﻿using System;
using System.Collections.Generic;
using System.ServiceModel;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.TaulesBase;

namespace Gaudeix.Admin.Forms.Admin
{
    public partial class EditParametreChild : Form, IChildForm
    {
        #region Variables privades
        // Constants
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_GUARDAR_CANVIS = "GuardarCanvis";

        // Variables privades
        private ParametreModel parametre;
        private IParentFormUpdatable parentForm = null;
        #endregion

        #region Constructors
        public EditParametreChild(ParametreModel parametre, IParentFormUpdatable formulariPare)
            : this()
        {
            this.parentForm = formulariPare;
            this.parametre = parametre;
            this.CarregarParametre(parametre);
        }

        private EditParametreChild()
        {
            InitializeComponent();
            InitializeControls();
        }

        #endregion

        #region Mètodes interns
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            // Carreguem el combo de provincies
            titolMain.Image = CommonResources.IconEmpreses.ToBitmap();
        }

        /// <summary>
        /// Carrega les dades del paràmetre a modificar
        /// </summary>
        /// <param name="parametre">Dades del paràmetre</param>
        private void CarregarParametre(ParametreModel parametre)
        {
            this.grpCanviValor.Text = String.Format("Paràmetre: {0}", parametre.CodiParametre);
            this.txtDescripcio.Text = parametre.Descripcio;
            this.txtValorActual.Text = parametre.Valor;
        }

        /// <summary>
        /// Guarda el nou valor del paràmetre
        /// </summary>
        private void GuardarNouValor()
        {
            TaulesBaseClient client = null;
            try
            {
                if (FormUtils.MissatgeConfirmacio(CommonResources.ConfirmarGuardar))
                {
                    client = WcfFactory.GetTaulesBaseClient();
                    client.UpdateParamValue(this.parametre.IdParametre, this.txtNouValor.Text);
                    FormUtils.MissatgeOperacioOk(CommonResources.InfoDadesGuardades);
                }
            }
            catch (FaultException f)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsTrobatGuardar + "\n" + f.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            
        }

        /// <summary>
        /// Tanca el formulari, i avisa al formulari pare per a que actualitzi les dades
        /// </summary>
        private void TancarFormulari()
        {
            this.parentForm.UpdateResults();
            this.Close();
        }
        #endregion

        #region IChildForm Members

        public IList<ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconGuardar.ToBitmap(), "Guardar canvis", MENU_GUARDAR_CANVIS));
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    TancarFormulari();
                    break;
                case MENU_GUARDAR_CANVIS:
                    GuardarNouValor();
                    break;
            }
        }


        #endregion


    }
}
