﻿using System;
using System.Collections.Generic;
using System.ServiceModel;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Infrastructure.Events;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.TaulesBase;

namespace Gaudeix.Admin.Forms.Admin
{
    public partial class GestioParametres : Form, IParentFormUpdatable
    {
        #region Propietats privades
        private const String MENU_TANCAR = "Tancar";
        private const String MENU_EDITAR = "Editar";
        #endregion

        #region Constructors
        public GestioParametres()
        {
            InitializeComponent();
            this.InitializeControls();
        }
        #endregion

        #region Mètodes privats
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            this.titolMain.Image = CommonResources.IconParametres.ToBitmap();

            this.gridData.Columns[colId.Name].DataPropertyName = "IdParametre";
            this.gridData.Columns[colCodi.Name].DataPropertyName = "CodiParametre";
            this.gridData.Columns[colDescripcio.Name].DataPropertyName = "Descripcio";
            this.gridData.Columns[colValor.Name].DataPropertyName = "Valor";

            this.CarregarParametres();
        }

        /// <summary>
        /// Carrega els paràmetres al grid
        /// </summary>
        private void CarregarParametres()
        {
            TaulesBaseClient client = null;
            ParametreModel[] parametres;
            try
            {
                client = WcfFactory.GetTaulesBaseClient();
                parametres = client.GetAllParametres();
                this.gridData.DataSource = parametres;
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsOperacio + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
        }

        /// <summary>
        /// Obre la pantalla d'edició del paràmetre seleccionat
        /// </summary>
        /// <param name="filaSeleccionada"></param>
        private void EditParam(int filaSeleccionada)
        {
            object id = gridData.Rows[filaSeleccionada].Cells[colId.Name].Value;
            ParametreModel parametre = new ParametreModel();
            parametre.IdParametre = ParseUtils.ParseInt32(id.ToString());
            parametre.CodiParametre = gridData.Rows[filaSeleccionada].Cells[colCodi.Name].Value.ToString();
            parametre.Descripcio = gridData.Rows[filaSeleccionada].Cells[colDescripcio.Name].Value.ToString();
            parametre.Valor = gridData.Rows[filaSeleccionada].Cells[colValor.Name].Value.ToString();

            this.OnShowChildForm(new ChildFormEventArgs(new EditParametreChild(parametre, this)));
        }
        #endregion

        #region IParentFormUpdatable Members

        public IList<Entities.Menu.ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconEditar.ToBitmap(), "Editar", MENU_EDITAR));
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_EDITAR:
                    if (gridData.SelectedCells.Count > 0)
                    {
                        this.EditParam(gridData.SelectedCells[0].RowIndex);
                    }
                    else
                    {
                        FormUtils.MissatgeAlerta("És necessari seleccionar primer un element de la llista");
                    }
                    break;
            }
        }

        public event EventHandler<Infrastructure.Events.ChildFormEventArgs> ShowChildForm;

        public void UpdateResults()
        {
            this.CarregarParametres();
        }

        #endregion

        #region Control dels events
        private void gridData_CellDoubleClick(object sender, DataGridViewCellEventArgs e)
        {
            // Obrim formulari per a modificar el valor
            this.EditParam(e.RowIndex);
        }

        /// <summary>
        /// Evita que es dispari l'event si no hi ha cap controlador escoltant.
        /// </summary>
        /// <param name="e">Paràmetres de l'event</param>
        protected virtual void OnShowChildForm(ChildFormEventArgs e)
        {
            // Fem una copia temporal del event per a evitar la possibilitat de que 
            // el subscriptor anuli la subscripció quan es dispari l'event
            EventHandler<ChildFormEventArgs> handler = ShowChildForm;
            if (handler != null)
            {
                handler(this, e);
            }
        }
        #endregion
    }
}
