﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.ServiceModel;
using System.Windows.Forms;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.TaulesBase;

namespace Gaudeix.Admin.Forms.Categories
{
    public partial class PopUpSearchCategories : Form
    {
        #region Propietats públiques
        public int[] selectedIds;
        public string[] selectedNames;
        #endregion

        #region Constructors
        public PopUpSearchCategories()
        {
            InitializeComponent();
            this.titolMain.Image = CommonResources.IconCategories.ToBitmap();
            InitializeList();
        }

        public PopUpSearchCategories(int[] idsCategories)
            : this()
        {
            this.selectedIds = idsCategories;
            if (this.selectedIds != null)
            {
                CheckItems(selectedIds);
            }
        }
        #endregion

        #region Mètodes privats
        /// <summary>
        /// Inicialitza la llista de categories
        /// </summary>
        private void InitializeList()
        {
            TaulesBaseClient client = null;
            ItemIdDescripcio[] categories;
            try
            {
                client = WcfFactory.GetTaulesBaseClient();
                categories = client.GetLlistaCategories();
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsOperacio + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            this.CarregarResultats(categories);
        }

        /// <summary>
        /// Selecciona els items corresponents als ID's passats
        /// </summary>
        /// <param name="ids">ID's a seleccionar</param>
        private void CheckItems(int[] ids)
        {
            foreach (ListViewItem item in lsvCategories.Items)
            {
                if (ids.Contains((int)item.Tag))
                {
                    item.Checked = true;
                }
            }
        }

        /// <summary>
        /// Carrega la llista de categories al listview
        /// </summary>
        /// <param name="categories">Categories a carregar</param>
        private void CarregarResultats(ItemIdDescripcio[] categories)
        {
            this.lsvCategories.Items.Clear();
            ListViewItem item;
            foreach (ItemIdDescripcio categoria in categories)
            {
                if (categoria.Id > 0)
                {
                    item = lsvCategories.Items.Add(String.Empty);
                    item.Tag = categoria.Id;
                    item.SubItems.Add(categoria.Descripcio);
                }
            }

        }

        /// <summary>
        /// Cancela la selecció, i tanca la pantalla
        /// </summary>
        private void Cancelar()
        {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.Close();
        }

        /// <summary>
        /// Accepta la selecció, i tanca la pantalla
        /// </summary>
        private void AcceptaSeleccio()
        {
            //if (lsvCategories.CheckedItems.Count == 0)
            //{
            //    FormUtils.MissatgeAlerta(CommonResources.SeleccioniElement);
            //    return;
            //}

            IList<int> ids = new List<int>();
            IList<string> noms = new List<string>();
            foreach (ListViewItem item in lsvCategories.CheckedItems)
            {
                ids.Add((int)item.Tag);
                noms.Add(item.SubItems[this.colName.Index].Text);
            }
            this.selectedIds = ids.ToArray<int>();
            this.selectedNames = noms.ToArray<string>();
            this.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.Close();
        }
        #endregion

        #region Control dels events
        private void chkSelTot_CheckedChanged(object sender, EventArgs e)
        {
            FormUtils.CheckItemsListView(chkSelTot.Checked, this.lsvCategories);
        }

        private void btnAcceptar_Click(object sender, EventArgs e)
        {
            this.AcceptaSeleccio();
        }

        private void btnCancelar_Click(object sender, EventArgs e)
        {
            this.Cancelar();
        }

        #endregion


    }
}
