﻿using System;
using System.Collections.Generic;
using System.ServiceModel;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Forms.Entitats;
using Gaudeix.Admin.Infrastructure.Events;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.Compres;

namespace Gaudeix.Admin.Forms.Compres
{
    public partial class SearchCompres : Form, IParentForm
    {
        #region Variables privades
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_EXECUTAR_CONSULTA = "ExecConsulta";

        private int[] IdsCategories = null;
        private int IdEmpresa = 0;
        #endregion

        #region Constructors
        public SearchCompres()
        {
            InitializeComponent();
            InitializeControls();
        }
        #endregion

        #region Mètodes privats
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            // Carreguem el combo de provincies
            FormUtils.CarregaCombo(this.cboProvincia, WcfUtils.GetProvincies());
            titolMain.Image = CommonResources.IconCompres.ToBitmap();
        }

        /// <summary>
        /// Executa la consulta de compres a través de WCF
        /// </summary>
        private void ExecutarConsulta()
        {
            CompresClient client = null;
            ItemLlistaCompres[] compres = null;
            try
            {
                // Recopilem els paràmetres
                ParamsSearchCompres parametres = new ParamsSearchCompres();
                parametres.IdEmpresa = this.IdEmpresa;
                parametres.Titol = txtTitol.Text;
                parametres.PreuBaseDesDe = ParseUtils.ParseDecimal(txtPreuBaseDesDe.Text);
                parametres.PreuBaseFins = ParseUtils.ParseDecimal(txtPreuBaseFins.Text);
                parametres.PreuVendaDesDe = ParseUtils.ParseDecimal(txtPreuVendaDesDe.Text);
                parametres.PreuVendaFins = ParseUtils.ParseDecimal(txtPreuVendaFins.Text);
                parametres.DataIniciDesDe = ParseUtils.ParseDateTime(txtDataIniDesDe.Text);
                parametres.DataIniciFins = ParseUtils.ParseDateTime(txtDataIniFins.Text);
                parametres.DataFiDesDe = ParseUtils.ParseDateTime(txtDataFiDesDe.Text);
                parametres.DataFiFins = ParseUtils.ParseDateTime(txtDataFiFins.Text);
                parametres.IdProvincia = (int)cboProvincia.SelectedValue;
                parametres.IdPoblacio = (int)cboPoblacio.SelectedValue;
                parametres.Categories = this.IdsCategories;

                // Cridem a WCF
                client = WcfFactory.GetCompresClient();
                compres = client.ConsultarCompres(parametres);
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsOperacio + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            this.CarregarResultats(compres);

        }

        /// <summary>
        /// Carrega els resultats de la consulta retornats per WCF
        /// </summary>
        /// <param name="llista">Llista de resultats</param>
        private void CarregarResultats(ItemLlistaCompres[] llista)
        {
            this.lsvResultats.Items.Clear();
            if (llista.Length == 0)
            {
                FormUtils.MissatgeInformacio(CommonResources.InfoNoRegistres);
                return;
            }
            ListViewItem item;
            foreach (ItemLlistaCompres compra in llista)
            {
                item = lsvResultats.Items.Add(compra.NomEmpresa);
                item.Tag = compra.IdCompra;
                item.SubItems.Add(compra.Titol);
                item.SubItems.Add(FormatUtils.FormatImport(compra.PreuBase));
                item.SubItems.Add(FormatUtils.FormatImport(compra.PreuVenda));
                item.SubItems.Add(FormatUtils.FormatInt32(compra.NumCompres));
                item.SubItems.Add(FormatUtils.FormatDecimal(compra.Valoracio));
            }
        }
        #endregion

        #region IParentForm Members

        public event EventHandler<Infrastructure.Events.ChildFormEventArgs> ShowChildForm;

        public IList<ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconCercar.ToBitmap(), "Executar consulta", MENU_EXECUTAR_CONSULTA));
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_EXECUTAR_CONSULTA:
                    this.ExecutarConsulta();
                    break;
            }
        }

        #endregion

        #region Control dels events interns
        private void cboProvincia_SelectedIndexChanged(object sender, EventArgs e)
        {
            int idProvincia = (int)cboProvincia.SelectedValue;
            // Carreguem les poblacions en base al id de provincia seleccionat
            FormUtils.CarregaCombo(cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(idProvincia));
        }

        /// <summary>
        /// Evita que es dispari l'event si no hi ha cap controlador escoltant.
        /// </summary>
        /// <param name="e">Paràmetres de l'event</param>
        protected virtual void OnShowChildForm(ChildFormEventArgs e)
        {
            // Fem una copia temporal del event per a evitar la possibilitat de que 
            // el subscriptor anuli la subscripció quan es dispari l'event
            EventHandler<ChildFormEventArgs> handler = ShowChildForm;
            if (handler != null)
            {
                handler(this, e);
            }
        }
       

        private void btnEmpresa_Click(object sender, EventArgs e)
        {
            PopUpSearchEntitat entitat = new PopUpSearchEntitat();
            entitat.SelectOnlyOne = true;
            if (entitat.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                this.IdEmpresa = entitat.selectedIds[0];
                this.txtEmpresa.Text = entitat.selectedNames[0];
            }
        }
        #endregion
    }
}
