﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.ServiceModel;
using System.Windows.Forms;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.Entitats;
using Gaudeix.Admin.WCF.Services.TaulesBase;

namespace Gaudeix.Admin.Forms.Entitats
{
    public partial class PopUpSearchEntitat : Form
    {
        #region Propietats del formulari
        public bool SelectOnlyOne = false;
        public int[] selectedIds = null;
        public string[] selectedNames = null;
        #endregion

        #region Constructors
        public PopUpSearchEntitat()
        {
            InitializeComponent();
            InitializeControls();
        }
        #endregion

        #region Mètodes interns
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            // Carreguem el combo de provincies
            FormUtils.CarregaCombo(this.cboProvincia, WcfUtils.GetProvincies());
            titolMain.Image = CommonResources.IconEmpreses.ToBitmap();
        }

        /// <summary>
        /// Cancel·la els canvis, i tanca el formulari
        /// </summary>
        private void Cancelar()
        {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.Close();
        }

        /// <summary>
        /// Accepta la selecció, i tanca el formulari
        /// </summary>
        private void AcceptaSeleccio()
        {
            if (lsvResultats.CheckedItems.Count == 0)
            {
                FormUtils.MissatgeAlerta(CommonResources.SeleccioniElement);
                return;
            }

            if (lsvResultats.CheckedItems.Count > 1)
            {
                FormUtils.MissatgeAlerta(CommonResources.SeleccioniUnElement);
                return;
            }

            IList<int> ids = new List<int>();
            IList<string> noms = new List<string>();
            foreach (ListViewItem item in lsvResultats.CheckedItems)
            {
                ids.Add((int)item.Tag);
                noms.Add(item.SubItems[1].Text);
            }
            this.selectedIds = ids.ToArray<int>();
            this.selectedNames = noms.ToArray<string>();
            this.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.Close();
        }

        /// <summary>
        /// Executa la consulta de registres
        /// </summary>
        private void ExecutarConsulta()
        {

            int idProvincia = 0;
            int idPoblacio = 0;

            if (cboProvincia.SelectedItem != null)
            {
                idProvincia = ((ItemIdDescripcio)cboProvincia.SelectedItem).Id;
            }
            if (cboPoblacio.SelectedItem != null)
            {
                idPoblacio = ((ItemIdDescripcio)cboPoblacio.SelectedItem).Id;
            }
            EntitatsClient client = null;
            ItemLlistaEmpreses[] entitats = null;
            try
            {
                client = WcfFactory.GetEntitatsClient();
                ParamsSearchEmpreses parametres = new ParamsSearchEmpreses();
                parametres.Nom = txtNom.Text;
                parametres.Cif = txtCif.Text;
                parametres.Email = txtEMail.Text;
                parametres.IdProvincia = (int)cboProvincia.SelectedValue;
                parametres.IdPoblacio = (int)cboPoblacio.SelectedValue;
                entitats = client.ConsultarEntitats(parametres);
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsOperacio + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            this.CarregarResultats(entitats);

        }

        /// <summary>
        /// Carrega els resultats de la consulta
        /// </summary>
        /// <param name="llista">Resultats a carregar</param>
        private void CarregarResultats(ItemLlistaEmpreses[] llista)
        {
            this.lsvResultats.Items.Clear();
            ListViewItem item;
            foreach (ItemLlistaEmpreses empresa in llista)
            {
                item = lsvResultats.Items.Add(String.Empty);
                item.Tag = empresa.Id;
                item.SubItems.Add(empresa.Nom);
                item.SubItems.Add(empresa.Cif);
                item.SubItems.Add(empresa.EMail);
                item.SubItems.Add(empresa.NomProvincia);
                item.SubItems.Add(empresa.NomPoblacio);
            }
        }
        #endregion

        #region Control dels events
        private void cboProvincia_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Carreguem les poblacions en base al id de provincia seleccionat
            //int idProvincia = ((ItemIdDescripcio)cboProvincia.SelectedItem).Id;
            int idProvincia = (int)cboProvincia.SelectedValue;
            FormUtils.CarregaCombo(this.cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(idProvincia));
        }

        private void btnCercar_Click(object sender, EventArgs e)
        {
            this.ExecutarConsulta();
        }

        private void btnAcceptar_Click(object sender, EventArgs e)
        {
            this.AcceptaSeleccio();
        }

        private void btnCancelar_Click(object sender, EventArgs e)
        {
            this.Cancelar();
        }

        private void chkSelTot_CheckedChanged(object sender, EventArgs e)
        {
            FormUtils.CheckItemsListView(chkSelTot.Checked, this.lsvResultats);
        }

        private void lsvResultats_DoubleClick(object sender, EventArgs e)
        {
            this.AcceptaSeleccio();
        }

        #endregion
    }
}
