﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.ServiceModel;
using System.Text;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Forms.Enviaments;
using Gaudeix.Admin.Infrastructure.Events;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.Entitats;
using Gaudeix.Admin.WCF.Services.TaulesBase;

namespace Gaudeix.Admin.Forms.Entitats
{
    public partial class SearchEntitats : Form, IParentForm
    {
        #region Variables privades
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_EXECUTAR_CONSULTA = "ExecConsulta";
        private const string MENU_CREAR = "CrearNova";
        private const string MENU_EDITAR = "Editar";
        private const string MENU_ESBORRAR_SELECCIONATS = "EsborrarSeleccionades";
        private const string MENU_ENVIAR_CORREU = "EnviarCorreu";
        #endregion

        #region Constructors
        public SearchEntitats()
        {
            InitializeComponent();
            InitializeControls();
        }
        #endregion

        #region Mètodes privats
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            // Carreguem el combo de provincies
            FormUtils.CarregaCombo(this.cboProvincia, WcfUtils.GetProvincies());
            titolMain.Image = CommonResources.IconEmpreses.ToBitmap();
        }

        /// <summary>
        /// Obre l'element seleccionat per edició
        /// </summary>
        private void EditarSeleccionat()
        {
            if (lsvResultats.SelectedItems.Count > 0)
            {
                int idEmpresa = (int)lsvResultats.SelectedItems[0].Tag;
                this.ObrirDetall(idEmpresa);
            }
        }

        /// <summary>
        /// Obre la pantalla de detall, ja sigui per a afegir un nou registre, o per modificar un d'existent.
        /// </summary>
        /// <param name="idEmpresa">Codi d'empresa a modificar. 
        /// Si s'informa, es carrega la pantalla per a modificar, i si es passa un 0 s'obre 
        /// pantalla per a crear un nou registre.</param>
        private void ObrirDetall(int idEmpresa)
        {
            if (idEmpresa > 0)
            {
                this.OnShowChildForm(new ChildFormEventArgs(new DetailEntitat(idEmpresa)));
            }
            else
            {
                this.OnShowChildForm(new ChildFormEventArgs(new DetailEntitat()));
            }


        }

        /// <summary>
        /// Executa la consulta d'entitats a través de WCF
        /// </summary>
        private void ExecutarConsulta()
        {
            EntitatsClient client = null;
            ItemLlistaEmpreses[] entitats = null;
            try
            {
                client = WcfFactory.GetEntitatsClient();
                ParamsSearchEmpreses parametres = new ParamsSearchEmpreses();
                parametres.Nom = txtNom.Text;
                parametres.Cif = txtCif.Text;
                parametres.Email = txtEMail.Text;
                parametres.IdProvincia = (int)cboProvincia.SelectedValue;
                parametres.IdPoblacio = (int)cboPoblacio.SelectedValue;
                entitats = client.ConsultarEntitats(parametres);
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsOperacio + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            this.CarregarResultats(entitats);
        }

        /// <summary>
        /// Carrega els resultats de la consulta retornats per WCF
        /// </summary>
        /// <param name="llista">Llista de resultats</param>
        private void CarregarResultats(ItemLlistaEmpreses[] llista)
        {
            this.lsvResultats.Items.Clear();
            if (llista.Length == 0)
            {
                FormUtils.MissatgeInformacio(CommonResources.InfoNoRegistres);
                return;
            }
            ListViewItem item;
            foreach (ItemLlistaEmpreses empresa in llista)
            {
                item = lsvResultats.Items.Add(String.Empty);
                item.Tag = empresa.Id;
                item.SubItems.Add(empresa.Nom);
                item.SubItems.Add(empresa.Cif);
                item.SubItems.Add(empresa.EMail);
                item.SubItems.Add(empresa.NomProvincia);
                item.SubItems.Add(empresa.NomPoblacio);
            }
        }

        /// <summary>
        /// Envia un correu electrònic a les empreses seleccionades
        /// </summary>
        private void SendMails()
        {
            // Recuperem les adreces dels destinataris
            if (lsvResultats.CheckedItems.Count <= 0)
            {
                FormUtils.MissatgeError("Com a mínim s'ha de seleccionar un element de la llista");
                return;
            }
            StringBuilder address = new StringBuilder();
            foreach (ListViewItem item in lsvResultats.CheckedItems)
            {
                address.Append(item.SubItems[colMail.Index].Text);
                address.Append(";");
            }
            string[] recipients = address.ToString().Split(new char[] { ';' });
            // Cridem al formulari fill
            this.OnShowChildForm(new ChildFormEventArgs(new EnviarCorreuChild(recipients)));
        }

        /// <summary>
        /// Esborra els elements seleccionats de la llistaº
        /// </summary>
        private void EsborrarSeleccionats()
        {
            EntitatsClient client = null;
            try
            {
                if (lsvResultats.CheckedItems.Count == 0)
                {
                    FormUtils.MissatgeError(CommonResources.SeleccioniElement);
                }
                if (!FormUtils.MissatgeConfirmacio(CommonResources.ConfirmarEliminacio))
                {
                    return;
                }
                IList<int> ids = new List<int>();
                foreach (ListViewItem item in lsvResultats.CheckedItems)
                {
                    ids.Add((int)item.Tag);
                }
                client = WcfFactory.GetEntitatsClient();
                client.EsborrarEmpreses(ids.ToArray<int>());
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsOperacio + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
        }
        #endregion

        #region IParentForm Members

        public IList<ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconCercar.ToBitmap(), "Executar consulta", MENU_EXECUTAR_CONSULTA));
            resultat.Add(new ItemMenu(CommonResources.IconAfegir.ToBitmap(), "Crear nova entitat", MENU_CREAR));
            resultat.Add(new ItemMenu(CommonResources.IconEditar.ToBitmap(), "Editar entitat", MENU_EDITAR));
            resultat.Add(new ItemMenu(CommonResources.IconEsborrar.ToBitmap(), "Esborrar seleccionades", MENU_ESBORRAR_SELECCIONATS));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconMail.ToBitmap(), "Enviar correu", MENU_ENVIAR_CORREU));
            return resultat;
        }

        public void ExecuteCommand(string command)
        {

            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_EXECUTAR_CONSULTA:
                    this.ExecutarConsulta();
                    break;
                case MENU_CREAR:
                    this.ObrirDetall(0);
                    break;
                case MENU_EDITAR:
                    this.EditarSeleccionat();
                    break;
                case MENU_ESBORRAR_SELECCIONATS:
                    this.EsborrarSeleccionats();
                    break;
                case MENU_ENVIAR_CORREU:
                    this.SendMails();
                    break;
            }
        }


        #endregion

        #region Control d'events
        /// <summary>
        /// Event que informa al formulari base per a que mostri un formulari fill
        /// </summary>
        public event EventHandler<ChildFormEventArgs> ShowChildForm;

        /// <summary>
        /// Evita que es dispari l'event si no hi ha cap controlador escoltant.
        /// </summary>
        /// <param name="e">Paràmetres de l'event</param>
        protected virtual void OnShowChildForm(ChildFormEventArgs e)
        {
            // Fem una copia temporal del event per a evitar la possibilitat de que 
            // el subscriptor anuli la subscripció quan es dispari l'event
            EventHandler<ChildFormEventArgs> handler = ShowChildForm;
            if (handler != null)
            {
                handler(this, e);
            }
        }

        private void cboProvincia_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Carreguem les poblacions en base al id de provincia seleccionat
            int idProvincia = ((ItemIdDescripcio)cboProvincia.SelectedItem).Id;
            FormUtils.CarregaCombo(this.cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(idProvincia));
        }

        private void chkSelTot_CheckedChanged(object sender, EventArgs e)
        {
            FormUtils.CheckItemsListView(chkSelTot.Checked, this.lsvResultats);
        }

        private void lsvResultats_DoubleClick(object sender, EventArgs e)
        {
            this.EditarSeleccionat();
        }

        #endregion
    }
}
