﻿using System;
using System.Collections.Generic;
using System.ServiceModel;
using System.Text;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.EMail;

namespace Gaudeix.Admin.Forms.Enviaments
{
    public partial class EnviarCorreuChild : Form, IChildForm
    {
        #region Propietats del formulari
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_ENVIAR = "Enviar";

        private const string ADDRESS_SEPARATOR = "; ";
        #endregion

        #region Constructors
        public EnviarCorreuChild(string[] mails)
            : this()
        {
            txtDestinataris.Text = String.Join(ADDRESS_SEPARATOR, mails);
        }

        private EnviarCorreuChild()
        {
            InitializeComponent();
            InitializeControls();
        }
        #endregion

        #region Mètodes interns
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            titolMain.Image = CommonResources.IconMail.ToBitmap();
        }

        /// <summary>
        /// Envia el correu als usuaris seleccionats
        /// </summary>
        private void EnviarCorreu()
        {
            EMailClient client = null;
            try
            {
                StringBuilder errors = new StringBuilder();

                // Validaciones de integridad
                if (String.IsNullOrEmpty(txtDestinataris.Text))
                {
                    errors.Append("    - Com a mínim s'ha d'informar un destinatari");
                }
                if (string.IsNullOrEmpty(txtTitol.Text))
                {
                    errors.Append("    - S'ha d'informar el títol del correu");
                }
                if (string.IsNullOrEmpty(txtText.Text))
                {
                    errors.Append("    - S'ha d'informar el text del correu");
                }
                if (errors.Length > 0)
                {
                    FormUtils.MissatgeError("S'han trobat els següents errors:\n" + errors.ToString());
                    return;
                }

                // Solicitem confirmació a l'usuari
                if (FormUtils.MissatgeConfirmacio("Està segur de que vol enviar el correu electrònic?"))
                {
                    client = WcfFactory.GetEMailClient();
                    string[] destinataris = txtDestinataris.Text.Split(new string[] { ADDRESS_SEPARATOR.Trim(), " " }, StringSplitOptions.RemoveEmptyEntries);
                    client.EnqueueMultirecipientMail(destinataris, txtTitol.Text, txtText.Text);
                    FormUtils.MissatgeOperacioOk("La petició s'ha processat correctament");
                }
                else
                {
                    FormUtils.MissatgeAlerta("Operació cancel·lada per l'usuari");
                }
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregar + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
        }

        #endregion

        #region IChildForm Members

        public IList<Entities.Menu.ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconMail.ToBitmap(), "Enviar correu", MENU_ENVIAR));
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_ENVIAR:
                    EnviarCorreu();
                    break;
            }
        }

        #endregion

    }
}
