﻿using System;
using System.Collections.Generic;
using System.ServiceModel;
using System.Text;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Infrastructure.Events;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.EMail;

namespace Gaudeix.Admin.Forms.Enviaments
{
    public partial class EnviarCorreuGeneral : Form, IParentForm
    {
        #region Propietats privades i constants
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_ENVIAR = "Enviar";

        #endregion

        #region Constructors
        public EnviarCorreuGeneral()
        {
            InitializeComponent();
            InitializeControls();
        }
        #endregion

        #region Mètodes privats
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            titolMain.Image = CommonResources.IconMail.ToBitmap();
            radUsers.Checked = true;
        }

        /// <summary>
        /// Envia els correus als destinataris seleccionats
        /// </summary>
        private void SendMails()
        {
            EMailClient client = null;
            try
            {
                StringBuilder errors = new StringBuilder();
                // Validaciones de integridad

                if (string.IsNullOrEmpty(txtTitol.Text))
                {
                    errors.AppendLine("    - S'ha d'informar el títol del correu");
                }
                if (string.IsNullOrEmpty(txtMissatge.Text))
                {
                    errors.AppendLine("    - S'ha d'informar el text del correu");
                }
                if (errors.Length > 0)
                {
                    FormUtils.MissatgeError("S'han trobat els següents errors:\r\n" + errors.ToString());
                    return;
                }

                // Solicitem confirmació a l'usuari
                if (FormUtils.MissatgeConfirmacio("Està segur de que vol enviar el correu electrònic?"))
                {
                    client = WcfFactory.GetEMailClient();
                    client.EnqueueGlobalMail(radUsers.Checked, radEmpreses.Checked, txtTitol.Text, txtMissatge.Text);
                    FormUtils.MissatgeOperacioOk("La petició s'ha processat correctament");
                }
                else
                {
                    FormUtils.MissatgeAlerta("Operació cancel·lada per l'usuari");
                }
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregar + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
        }
        #endregion

        #region IChildForm Members
        public event System.EventHandler<Infrastructure.Events.ChildFormEventArgs> ShowChildForm;

        public IList<ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconMail.ToBitmap(), "Enviar correu", MENU_ENVIAR));
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_ENVIAR:
                    this.SendMails();
                    break;
            }
        }

        #endregion

        #region Control d'events
        /// <summary>
        /// Evita que es dispari l'event si no hi ha cap controlador escoltant.
        /// </summary>
        /// <param name="e">Paràmetres de l'event</param>
        protected virtual void OnShowChildForm(ChildFormEventArgs e)
        {
            // Fem una copia temporal del event per a evitar la possibilitat de que 
            // el subscriptor anuli la subscripció quan es dispari l'event
            EventHandler<ChildFormEventArgs> handler = ShowChildForm;
            if (handler != null)
            {
                handler(this, e);
            }
        }
        #endregion

    }
}
