﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Infrastructure.Events;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.Estadistiques;

namespace Gaudeix.Admin.Forms
{
    public partial class MainForm : Form
    {

        #region Variables del formulari
        // Variables privades del formulari
        Dictionary<String, String> DisponibleForms;
        IParentForm currentForm = null;
        Form childForm = null;

        // Constants de noms de namespaces
        private const String NAMESPACE_ENTITATS = "Gaudeix.Admin.Forms.Entitats";
        private const String NAMESPACE_USUARIS = "Gaudeix.Admin.Forms.Usuaris";
        private const String NAMESPACE_COMPRES = "Gaudeix.Admin.Forms.Compres";
        private const String NAMESPACE_OFERTES = "Gaudeix.Admin.Forms.Ofertes";
        private const String NAMESPACE_ENVIAMENTS = "Gaudeix.Admin.Forms.Enviaments";
        private const String NAMESPACE_ADMIN = "Gaudeix.Admin.Forms.Admin";

        // Constants de noms de formularis
        private const String FORM_SEARCH_ENTITATS = "SearchEntitats";
        private const String FORM_SEARCH_USUARIS = "SearchUsuaris";
        private const String FORM_SEARCH_OFERTES = "SearchOfertes";
        private const String FORM_SEARCH_COMPRES = "SearchCompres";
        private const String FORM_SEND_MAIL = "EnviarCorreuGeneral";
        private const String FORM_GESTIO_PARAMETRES = "GestioParametres";

        // Constants d'informes disponibles
        private const string INFORME_VENDES = "Vendes";
        private const string INFORME_BENEFICIS = "Beneficis";
        private const string INFORME_REGISTRES = "Registres";
        private const string INFORME_PUBLICACIONS = "Publicacions";
        // Informes disponibles
        private  string[] informesDisponibles = new String[] 
                { INFORME_VENDES, INFORME_BENEFICIS, INFORME_REGISTRES, INFORME_PUBLICACIONS };
        // Index d'informe mostrat
        private int informeMostrat = 0;
        #endregion

        #region Constructors
        public MainForm()
        {
            InitializeComponent();
            this.Icon = CommonResources.IconApp;
            this.InicialitzaDiccionaris();
            this.toolMenu.Visible = false;
            // Mostrem el primer informe
            MostrarInforme(0);
        }

       
        #endregion

        #region Metodes privats del formulari

        /// <summary>
        /// Carrega i mostra el codi d'informe indicat
        /// </summary>
        /// <param name="codiInforme">Codi d'informe a consultar</param>
        private void MostrarInforme(int codiInforme)
        {
            informeMostrat = codiInforme;
            // Control dels possibles errors a l'index
            if (informeMostrat < 0)
            {
                informeMostrat = 0;
            }
            else if (informeMostrat > informesDisponibles.Length - 1)
            {
                informeMostrat = informesDisponibles.Length - 1;
            }
            // Actualitzar botons de canvi d'informe
            btnInformeAnterior.Enabled = (informeMostrat >0);
            btnInformeSeguent.Enabled = (informeMostrat < (informesDisponibles.Length - 1));

            switch (informesDisponibles[informeMostrat])
            {
                case INFORME_VENDES:
                    this.CarregarGraficVendes();
                    break;
                case INFORME_BENEFICIS:
                    this.CarregarGraficBeneficis();
                    break;
                case INFORME_REGISTRES:
                    this.CarregarGraficRegistres();
                    break;
                case INFORME_PUBLICACIONS:
                    this.CarregarGraficPublicacions();
                    break;
            }
        }

        /// <summary>
        /// Carrega el gràfic de publicacions d'ofertes al portal dels darrers set dies
        /// </summary>
        private void CarregarGraficPublicacions()
        {
            this.lblTitolInforme.Text = "Publicacions";
            // Netejem informe anterior
            chartEstadistiques.Series[0].Points.Clear();

            EstadistiquesClient client = null;
            try
            {
                client = WcfFactory.GetEstadistiquesClient();
                ItemDataValor[] valors = client.GetEstadisticaPublicacions();
                foreach (ItemDataValor valor in valors)
                {
                    chartEstadistiques.Series[0].Points.AddXY(valor.Data, valor.Valor);
                }
            }
            catch (Exception)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregarGrafic);
            }
            finally
            {
                if (client != null)
                {
                    client.Close();
                }
            }
        }

       /// <summary>
       /// Carrega el gràfic de registres al portal dels darrers set dies
       /// </summary>
        private void CarregarGraficRegistres()
        {
            this.lblTitolInforme.Text = "Registres d'usuari";

            // Netejem informe anterior
            chartEstadistiques.Series[0].Points.Clear();

            EstadistiquesClient client = null;
            try
            {
                client = WcfFactory.GetEstadistiquesClient();
                ItemDataValor[] valors = client.GetEstadisticaRegistres();
                foreach (ItemDataValor valor in valors)
                {
                    chartEstadistiques.Series[0].Points.AddXY(valor.Data, valor.Valor);
                }
            }
            catch (Exception)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregarGrafic);
            }
            finally
            {
                if (client != null)
                {
                    client.Close();
                }
            }

        }

        /// <summary>
        /// Carrega el gràfic de beneficis
        /// </summary>
        private void CarregarGraficBeneficis()
        {
            this.lblTitolInforme.Text = "Beneficis";

            // Netejem informe anterior
            chartEstadistiques.Series[0].Points.Clear();
            EstadistiquesClient client = null;
            try
            {
                client = WcfFactory.GetEstadistiquesClient();
                ItemDataValor[] valors = client.GetEstadisticaBeneficis();
                foreach (ItemDataValor valor in valors)
                {
                    chartEstadistiques.Series[0].Points.AddXY(valor.Data, valor.Valor);
                }
            }
            catch (Exception)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregarGrafic);
            }
            finally
            {
                if (client != null)
                {
                    client.Close();
                }
            }

        }

        /// <summary>
        /// Carrega el gràfic de vendes
        /// </summary>
        private void CarregarGraficVendes()
        {
            this.lblTitolInforme.Text = "Vendes";
            // Netejem informe anterior
            chartEstadistiques.Series[0].Points.Clear();
             EstadistiquesClient client=null;
            try
            {
                client= WcfFactory.GetEstadistiquesClient();
                ItemDataValor[] valors = client.GetEstadisticaVendes();
                foreach (ItemDataValor valor in valors)
                {
                    chartEstadistiques.Series[0].Points.AddXY(valor.Data, valor.Valor);
                }
            }
            catch (Exception)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregarGrafic);
            }
            finally
            {
                if (client != null)
                {
                    client.Close();
                }
            }

        }

        /// <summary>
        /// Inicialitza els diccionaris utilitzats per a gestionar els formularis disponibles a l'aplicació
        /// </summary>
        private void InicialitzaDiccionaris()
        {
            // Inicialitzem diccionari de formularis dispobibles
            this.DisponibleForms = new Dictionary<string, string>();
            // Carreguem els formularis disponibles
            this.DisponibleForms.Add(FORM_SEARCH_ENTITATS, NAMESPACE_ENTITATS + "." + FORM_SEARCH_ENTITATS);
            this.DisponibleForms.Add(FORM_SEARCH_OFERTES, NAMESPACE_OFERTES + "." + FORM_SEARCH_OFERTES);
            this.DisponibleForms.Add(FORM_SEARCH_USUARIS, NAMESPACE_USUARIS + "." + FORM_SEARCH_USUARIS);
            this.DisponibleForms.Add(FORM_SEARCH_COMPRES, NAMESPACE_COMPRES + "." + FORM_SEARCH_COMPRES);
            this.DisponibleForms.Add(FORM_SEND_MAIL, NAMESPACE_ENVIAMENTS + "." + FORM_SEND_MAIL);
            this.DisponibleForms.Add(FORM_GESTIO_PARAMETRES, NAMESPACE_ADMIN + "." + FORM_GESTIO_PARAMETRES);
        }

        /// <summary>
        /// Mostra un formulari al panel2.
        /// </summary>
        /// <param name="name">Nom del formulari</param>
        private void ShowForm(String name)
        {

            if (null != currentForm)
            {
                // Desactivem controlador d'event
                ((Form)currentForm).FormClosed -= new FormClosedEventHandler(this.currentForm_FormClosed);
                // Tanquem el formulari
                ((Form)currentForm).Close();
            }

            // El formulari no està carregat, l'instanciem per reflection
            Type type = Type.GetType(DisponibleForms[name]);
            IParentForm formulari = (IParentForm)Activator.CreateInstance(type);

            // Un cop creat, l'afegim a la llista de formularis carregats
            formulari = (IParentForm)this.initFormProperties((Form)formulari);

            // Inicialitzem els events del formulari necessaris per al framework
            ((Form)formulari).FormClosed += new FormClosedEventHandler(this.currentForm_FormClosed);
            formulari.ShowChildForm += new EventHandler<ChildFormEventArgs>(this.currentForm_ShowChildForm);
            this.currentForm = formulari;

            initFormulariMenu((Form)this.currentForm);

            // Portem el formulari al capdavant
            ((Form)formulari).BringToFront();
        }

        /// <summary>
        /// Inicialitza el formulari del menu
        /// </summary>
        /// <param name="form">Formulari que implementa la interficie IChildForm. 
        /// Si no implementa la interficie, no dibuixarà cap menú
        /// </param>
        private void initFormulariMenu(Form form)
        {
            toolMenu.Items.Clear();

            if ((null == form) || !(form is IChildForm))
            {
                this.toolMenu.Visible = false;
                return;
            }

            IList<ItemMenu> menu = ((IChildForm)form).GetFormMenu();
            ToolStripItem itemMenu;
            foreach (ItemMenu item in menu)
            {
                if (item.IsSeparador)
                {
                    itemMenu = new ToolStripSeparator();
                }
                else
                {
                    itemMenu = new ToolStripButton();
                    itemMenu.Image = item.Imatge;
                    itemMenu.Text = item.Titol;
                    itemMenu.ToolTipText = item.Titol;
                    itemMenu.Tag = item.Tag;
                }
                toolMenu.Items.Add(itemMenu);
            }
            toolMenu.Visible = true;
        }

        /// <summary>
        /// Inicialitza les propietats d'un formulari
        /// </summary>
        /// <param name="formulari">Formulari a inicialitzar</param>
        /// <returns>Formulari inicialitzat</returns>
        private Form initFormProperties(Form formulari)
        {
            // Inicialitzem propietats
            formulari.TopLevel = false;
            formulari.Parent = splitMain.Panel2;
            formulari.ControlBox = false;
            formulari.FormBorderStyle = FormBorderStyle.None;
            formulari.Text = String.Empty;
            formulari.Show();
            formulari.Dock = DockStyle.Fill;
            return formulari;
        }

        #endregion

        #region Controladors d'events
        private void btnEntitats_Click(object sender, EventArgs e)
        {
            this.ShowForm(FORM_SEARCH_ENTITATS);
        }

        private void btnUsuaris_Click(object sender, EventArgs e)
        {
            this.ShowForm(FORM_SEARCH_USUARIS);
        }

        private void btnOfertes_Click(object sender, EventArgs e)
        {
            this.ShowForm(FORM_SEARCH_OFERTES);
        }

        private void btnEnviamentCorreus_Click(object sender, EventArgs e)
        {
            this.ShowForm(FORM_SEND_MAIL);
        }

        private void currentForm_FormClosed(object sender, EventArgs e)
        {
            this.toolMenu.Items.Clear();
            this.toolMenu.Visible = false;
            currentForm = null;
            childForm = null;
        }

        private void childForm_FormClosed(object sender, EventArgs e)
        {
            childForm.FormClosed -= new FormClosedEventHandler(this.childForm_FormClosed);
            this.childForm = null;
            this.initFormulariMenu((Form)this.currentForm);
            ((Form)this.currentForm).BringToFront();
        }

        private void currentForm_ShowChildForm(object sender, ChildFormEventArgs e)
        {
            Form child = e.ChildForm;
            child = this.initFormProperties(child);

            child.FormClosed += new FormClosedEventHandler(this.childForm_FormClosed);

            initFormulariMenu(child);

            this.childForm = child;
            // Portem el formulari al capdavant
            this.childForm.BringToFront();
        }

        private void toolMenu_ItemClicked(object sender, ToolStripItemClickedEventArgs e)
        {
            if ((null != this.childForm) && (this.childForm is IChildForm))
            {
                // L'event prové del formulari fill
                ((IChildForm)this.childForm).ExecuteCommand(e.ClickedItem.Tag.ToString());
            }
            else if ((null != this.currentForm) && (this.currentForm is IChildForm))
            {
                // L'event prové del formulari pare
                ((IChildForm)this.currentForm).ExecuteCommand(e.ClickedItem.Tag.ToString());
            }
        }

        private void btnSortir_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void btnCompres_Click(object sender, EventArgs e)
        {
            this.ShowForm(FORM_SEARCH_COMPRES);
        }

        private void btnGestioParametres_Click(object sender, EventArgs e)
        {
            this.ShowForm(FORM_GESTIO_PARAMETRES);
        }

     
        private void btnInformeSeguent_Click(object sender, EventArgs e)
        {
            this.MostrarInforme(this.informeMostrat + 1);
        }

        private void btnInformeAnterior_Click(object sender, EventArgs e)
        {
            this.MostrarInforme(this.informeMostrat - 1);
        }
        #endregion

    }
}
