﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.ServiceModel;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Forms.Entitats;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.Ofertes;
using System.Text.RegularExpressions;

namespace Gaudeix.Admin.Forms.Ofertes
{
    public partial class DetailOferta : Form, IChildForm
    {
        #region Variables privades
        private const string CARACTER_BR = "<br/>";
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_GUARDAR_CANVIS = "GuardarCanvis";
        private const string MENU_ESBORRAR = "Esborrar";
        private int IdOferta;
        private int IdEmpresa;
        private byte[] imageData;
        #endregion

        #region Constructors
        public DetailOferta(int idOferta)
            : this()
        {
            this.IdOferta = idOferta;
            this.CarregarOferta(this.IdOferta);
        }


        public DetailOferta()
        {
            InitializeComponent();
            InitializeControls();
        }

        #endregion

        #region Mètodes privats
        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            // Carreguem el combo de provincies
            FormUtils.CarregaCombo(this.cboProvincia, WcfUtils.GetProvincies());
            // Carreguem el combo de categories
            FormUtils.CarregaCombo(this.cboCategoria, WcfUtils.GetCategories());
            titolMain.Image = CommonResources.IconOfertes.ToBitmap();
        }

        /// <summary>
        /// Carrega les dades de la oferta seleccionada
        /// </summary>
        /// <param name="idOferta">Codi de la oferta a carregar</param>
        private void CarregarOferta(int idOferta)
        {
            OfertesClient client = null;
            try
            {
                client = WcfFactory.GetOfertesClient();
                DetallOfertaWcf oferta = client.GetDetallOfertaForWCF(idOferta, true);
                this.IdOferta = oferta.IdOferta;
                this.IdEmpresa = oferta.IdEmpresa;
                txtEmpresa.Text = oferta.NomEmpresa;
                cboProvincia.SelectedValue = oferta.IdProvincia;
                FormUtils.CarregaCombo(cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(oferta.IdProvincia));
                cboPoblacio.SelectedValue = oferta.IdPoblacio;
                txtDataInici.Text = FormatUtils.FormatData(oferta.DataInici);
                txtDataFi.Text = FormatUtils.FormatData(oferta.DataFi);
                txtPreuBase.Text = FormatUtils.FormatDecimal(oferta.PreuBase);
                txtPreuVenda.Text = FormatUtils.FormatDecimal(oferta.PreuVenda);
                txtBenefici.Text = FormatUtils.FormatDecimal(oferta.Benefici);
                txtTitol.Text = oferta.Titol;
                txtDescripcio.Text = Regex.Replace(oferta.Descripcio, CARACTER_BR, "\r\n");
                txtNotaMitja.Text = FormatUtils.FormatDecimal(oferta.NotaMitja);
                txtDadesResum.Text = Regex.Replace(oferta.DadesResum, CARACTER_BR, "\r\n");
                txtDadesAddicionals.Text = Regex.Replace(oferta.DadesAddicionals, CARACTER_BR, "\r\n");
                txtDadesLocalitzacio.Text = Regex.Replace(oferta.DadesLocalitzacio, CARACTER_BR, "\r\n");
                txtNumVisites.Text = oferta.NumVisites.ToString();
                txtNumCompres.Text = oferta.NumCompres.ToString();
                cboCategoria.SelectedValue = oferta.IdCategoria;
                // Carreguem la foto
                this.picImatge.Image = ParseUtils.ParseImageFromByteArray(oferta.Imatge);
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregar + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
        }

        /// <summary>
        /// Guarda la oferta a la base de dades
        /// </summary>
        private void GuardarOferta()
        {
            OfertesClient client = null;
            try
            {
                if (!FormUtils.MissatgeConfirmacio(CommonResources.ConfirmarGuardar))
                {
                    return;
                }
                DetallOfertaWcf oferta = new DetallOfertaWcf();
                oferta.IdOferta = this.IdOferta;
                oferta.IdEmpresa = this.IdEmpresa;
                oferta.IdPoblacio = (int)cboPoblacio.SelectedValue;
                oferta.DataInici = ParseUtils.ParseDateTime(this.txtDataInici.Text);
                oferta.DataFi = ParseUtils.ParseDateTime(this.txtDataFi.Text);
                oferta.PreuBase = ParseUtils.ParseDecimal(this.txtPreuBase.Text);
                oferta.PreuVenda = ParseUtils.ParseDecimal(this.txtPreuVenda.Text);
                oferta.Titol = this.txtTitol.Text;
                oferta.Descripcio = Regex.Replace(this.txtDescripcio.Text, "\r\n", CARACTER_BR);
                oferta.NotaMitja = ParseUtils.ParseDecimal(this.txtNotaMitja.Text);
                oferta.DadesResum = Regex.Replace(this.txtDadesResum.Text, "\r\n", CARACTER_BR);
                oferta.DadesAddicionals = Regex.Replace(this.txtDadesAddicionals.Text, "\r\n", CARACTER_BR);
                oferta.DadesLocalitzacio = Regex.Replace(this.txtDadesLocalitzacio.Text, "\r\n", CARACTER_BR);
                oferta.NumVisites = ParseUtils.ParseInt32(txtNumVisites.Text);
                oferta.NumCompres = ParseUtils.ParseInt32(txtNumCompres.Text);
                oferta.IdCategoria = (int)cboCategoria.SelectedValue;
                oferta.Imatge = this.imageData;
                client = WcfFactory.GetOfertesClient();
                client.GuardarOfertaFromWCF(oferta);
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregar + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            FormUtils.MissatgeOperacioOk(CommonResources.InfoDadesGuardades);
        }

        /// <summary>
        /// Esborra la oferta de la base de dades
        /// </summary>
        private void EsborrarOferta()
        {
            OfertesClient client = null;
            try
            {
                if (!FormUtils.MissatgeConfirmacio(CommonResources.ConfirmarEliminacio))
                {
                    return;
                }
                client = WcfFactory.GetOfertesClient();
                client.EsborrarOfertes(new int[] { this.IdEmpresa });
            }
            catch (FaultException f)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsTrobatGuardar + "\n" + f.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            FormUtils.MissatgeOperacioOk(CommonResources.InfoRegistreEliminat);
        }

        /// <summary>
        /// Calcula el benefici entre el preu de venda i el de compra
        /// </summary>
        private void CalcularBenefici()
        {
            this.txtBenefici.Text = FormatUtils.FormatDecimal(ParseUtils.ParseDecimal(txtPreuVenda.Text) - ParseUtils.ParseDecimal(txtPreuBase.Text));
        }

        /// <summary>
        /// Carrega una nova imatge a la oferta
        /// </summary>
        private void CarregarImatge()
        {
            openFileDialog.Filter = "Imatges|*.jpg";
            openFileDialog.Title = "Seleccioni una imatge";
            DialogResult result = openFileDialog.ShowDialog();

            if (result == DialogResult.OK)
            {
                string rutaImatge = openFileDialog.FileName;
                // Validem la mida del fitxer
                long mida = new FileInfo(rutaImatge).Length;
                if (mida > 1048576)
                {
                    FormUtils.MissatgeError(CommonResources.ErrorImatgeGran);
                    return;
                }

                this.imageData = File.ReadAllBytes(openFileDialog.FileName);
                this.picImatge.Image = Image.FromFile(openFileDialog.FileName);
            }
        }

        #endregion

        #region Control d'events

        private void btnModificarImatge_Click(object sender, EventArgs e)
        {
            this.CarregarImatge();
        }

        private void cboProvincia_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Carreguem les poblacions en base al id de provincia seleccionat
            int idProvincia = (int)cboProvincia.SelectedValue;
            FormUtils.CarregaCombo(this.cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(idProvincia));
        }

        private void btnEmpresa_Click(object sender, EventArgs e)
        {
            PopUpSearchEntitat entitat = new PopUpSearchEntitat();
            entitat.SelectOnlyOne = true;
            if (entitat.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                this.IdEmpresa = entitat.selectedIds[0];
                this.txtEmpresa.Text = entitat.selectedNames[0];
            }
        }

        private void txtPreuBase_Leave(object sender, EventArgs e)
        {
            txtPreuBase.Text = FormatUtils.FormatDecimal(ParseUtils.ParseDecimal(txtPreuBase.Text));
            CalcularBenefici();
        }

        private void txtPreuVenda_Leave(object sender, EventArgs e)
        {
            txtPreuVenda.Text = FormatUtils.FormatDecimal(ParseUtils.ParseDecimal(txtPreuVenda.Text));
            CalcularBenefici();
        }
        #endregion

        #region IChildForm Members

        public IList<Entities.Menu.ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconGuardar.ToBitmap(), "Guardar canvis", MENU_GUARDAR_CANVIS));
            if (this.IdOferta > 0)
            {
                resultat.Add(new ItemMenu(CommonResources.IconEsborrar.ToBitmap(), "Esborrar", MENU_ESBORRAR));
            }
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_GUARDAR_CANVIS:
                    GuardarOferta();
                    break;
                case MENU_ESBORRAR:
                    EsborrarOferta();
                    break;
            }
        }

        #endregion



    }
}
