﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ServiceModel;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Forms.Categories;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.Usuaris;

namespace Gaudeix.Admin.Forms.Usuaris
{
    public partial class DetailUsuari : Form, IChildForm
    {
        #region Variables privades
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_GUARDAR_CANVIS = "GuardarCanvis";
        private const string MENU_ESBORRAR = "Esborrar";

        private int IdUsuari;
        private int[] IdsCategories;
        #endregion

        #region Constructors

        public DetailUsuari()
        {
            InitializeComponent();
            InitializeControls();
        }

        public DetailUsuari(int idUsuari)
            : this()
        {
            this.IdUsuari = idUsuari;
            this.CarregarUsuari(this.IdUsuari);
        }
        #endregion

        #region Mètodes privats
        /// <summary>
        /// Carrega les dades d'un usuari al formulari actual
        /// </summary>
        /// <param name="idUsuari">Codi d'usuari</param>
        private void CarregarUsuari(int idUsuari)
        {
            UsuarisClient client = null;
            try
            {
                client = WcfFactory.GetUsuarisClient();
                DetallUsuari usuari = client.GetDetallUsuari(idUsuari);
                this.IdUsuari = usuari.IdUsuari;
                this.txtNom.Text = usuari.Nom;
                this.txtCognom1.Text = usuari.Cognom1;
                this.txtCognom2.Text = usuari.Cognom2;
                this.txtNif.Text = usuari.Nif;
                txtEmail.Text = usuari.Email;
                txtCodiPostal.Text = usuari.CodiPostal;
                cboProvincia.SelectedValue = usuari.IdProvincia;
                FormUtils.CarregaCombo(cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(usuari.IdProvincia));
                cboPoblacio.SelectedValue = usuari.IdPoblacio;
                txtDataNaixement.Text = FormatUtils.FormatData(usuari.DataNaixement);
                txtCodiUsuari.Text = usuari.LoginUsuari;
                txtPreguntaClau.Text = usuari.PreguntaClau;
                txtRespostaClau.Text = usuari.RespostaClau;
                chkRebreEmail.Checked = usuari.MailOfertes;
                this.IdsCategories = usuari.LlistaCategories.Where(c => c.CategoriaActiva).Select(c => c.IdCategoria).ToArray();
                string[] categories = usuari.LlistaCategories.Where(c => c.CategoriaActiva).Select(c => c.Descripcio).ToArray();

                if (null != categories)
                {
                    this.txtInteressos.Text = String.Join(", ", categories);
                }
                else
                {
                    txtInteressos.Text = String.Empty;
                }
                CarregarCompres(usuari.LlistaCompres);
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregar + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
        }

        /// <summary>
        /// Carrega les compres de l'usuari al control corresponent
        /// </summary>
        /// <param name="compres">Llista de compres a carregar</param>
        private void CarregarCompres(ItemCompresUsuari[] compres)
        {
            lsvCompres.Items.Clear();
            ListViewItem item;
            if (null != compres)
            {
                foreach (ItemCompresUsuari compra in compres)
                {
                    item = lsvCompres.Items.Add(compra.Titol);
                    item.Tag = compra.IdCompra;
                    item.SubItems.Add(FormatUtils.FormatData(compra.DataCompra));
                    item.SubItems.Add(FormatUtils.FormatImport(compra.PreuBase));
                    item.SubItems.Add(FormatUtils.FormatImport(compra.PreuVenda));
                }
            }
        }

        /// <summary>
        /// Inicialitza els controls del formulari
        /// </summary>
        private void InitializeControls()
        {
            // Carreguem el combo de provincies
            FormUtils.CarregaCombo(this.cboProvincia, WcfUtils.GetProvincies());
            this.titolMain.Image = CommonResources.IconUsuaris.ToBitmap();
        }

        /// <summary>
        /// Guarda les dades de l'usuari
        /// </summary>
        private void GuardarUsuari()
        {
            UsuarisClient client = null;
            try
            {
                DetallUsuari usuari = new DetallUsuari();
                usuari.IdUsuari = this.IdUsuari;
                usuari.Adreca = txtAdreca.Text;
                usuari.CodiPostal = txtCodiPostal.Text;
                usuari.Cognom1 = txtCognom1.Text;
                usuari.Cognom2 = txtCognom2.Text;
                usuari.DataNaixement = ParseUtils.ParseDateTime(txtDataNaixement.Text);
                usuari.Email = txtEmail.Text;
                usuari.IdPoblacio = (int)cboPoblacio.SelectedValue;
                usuari.LoginPassword = txtContrasenya.Text;
                usuari.LoginPasswordConfirm = txtConfirmarContrasenya.Text;
                usuari.LoginUsuari = txtCodiUsuari.Text;
                usuari.MailOfertes = chkRebreEmail.Checked;
                usuari.Nif = txtNif.Text;
                usuari.Nom = txtNom.Text;
                usuari.PreguntaClau = txtPreguntaClau.Text;
                usuari.RespostaClau = txtRespostaClau.Text;
                IList<ItemLlistaCategories> categories = new List<ItemLlistaCategories>();
                ItemLlistaCategories categoria;
                foreach (int id in this.IdsCategories)
                {
                    categoria = new ItemLlistaCategories();
                    categoria.CategoriaActiva = true;
                    categoria.IdCategoria = id;
                    categories.Add(categoria);
                }
                usuari.LlistaCategories = categories.ToArray();
                client = WcfFactory.GetUsuarisClient();
                client.GuardarUsuari(usuari, (txtPreguntaClau.Text.Equals(String.Empty)));
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregar + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            FormUtils.MissatgeOperacioOk(CommonResources.InfoDadesGuardades);
        }

        /// <summary>
        /// Esborra els usuaris seleccionats
        /// </summary>
        private void EsborrarUsuari()
        {
            UsuarisClient client = null;
            try
            {
                if (!FormUtils.MissatgeConfirmacio(CommonResources.ConfirmarEliminacio))
                {
                    return;
                }
                client = WcfFactory.GetUsuarisClient();
                client.EsborrarUsuaris(new int[] { this.IdUsuari });
            }
            catch (FaultException f)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsTrobatGuardar + "\n" + f.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            FormUtils.MissatgeOperacioOk(CommonResources.InfoRegistreEliminat);
        }

        #endregion

        #region Control d'events
        private void cboProvincia_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Carreguem les poblacions en base al id de provincia seleccionat
            int idProvincia = (int)cboProvincia.SelectedValue;
            FormUtils.CarregaCombo(this.cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(idProvincia));
        }

        private void btnInteressos_Click(object sender, EventArgs e)
        {
            PopUpSearchCategories categories = new PopUpSearchCategories(this.IdsCategories);
            if (categories.ShowDialog(this) == DialogResult.OK)
            {
                this.IdsCategories = categories.selectedIds;
                this.txtInteressos.Text = String.Join(", ", categories.selectedNames);
            }
        }
        #endregion

        #region IChildForm Members

        public IList<Entities.Menu.ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconGuardar.ToBitmap(), "Guardar canvis", MENU_GUARDAR_CANVIS));
            if (this.IdUsuari > 0)
            {
                resultat.Add(new ItemMenu(CommonResources.IconEsborrar.ToBitmap(), "Esborrar", MENU_ESBORRAR));
            }
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_GUARDAR_CANVIS:
                    GuardarUsuari();
                    break;
                case MENU_ESBORRAR:
                    EsborrarUsuari();
                    break;
            }
        }

        #endregion
    }
}
