﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.ServiceModel;
using System.Text;
using System.Windows.Forms;
using Gaudeix.Admin.Entities.Menu;
using Gaudeix.Admin.Forms.Categories;
using Gaudeix.Admin.Forms.Enviaments;
using Gaudeix.Admin.Infrastructure.Events;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Infrastructure.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.Utils;
using Gaudeix.Admin.WCF.Services.Usuaris;
namespace Gaudeix.Admin.Forms.Usuaris
{
    public partial class SearchUsuaris : Form, IParentForm
    {
        #region Propietats privades
        private const string MENU_TANCAR = "Tancar";
        private const string MENU_EXECUTAR_CONSULTA = "ExecConsulta";
        private const string MENU_CREAR = "Crear";
        private const string MENU_ESBORRAR_SELECCIONATS = "EsborrarSeleccionats";
        private const string MENU_ENVIAR_CORREU = "EnviarCorreu";

        private int[] IdCategories;
        #endregion

        #region Declaració events públics
        public event EventHandler<Infrastructure.Events.ChildFormEventArgs> ShowChildForm;
        #endregion

        #region Constructors
        public SearchUsuaris()
        {
            InitializeComponent();
            InitializeControls();
        }
        #endregion

        #region IChildForm Members

        public IList<ItemMenu> GetFormMenu()
        {
            IList<ItemMenu> resultat = new List<ItemMenu>();
            resultat.Add(new ItemMenu(CommonResources.IconSortir.ToBitmap(), "Tancar", MENU_TANCAR));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconCercar.ToBitmap(), "Executar consulta", MENU_EXECUTAR_CONSULTA));
            resultat.Add(new ItemMenu(CommonResources.IconAfegir.ToBitmap(), "Crear usuari", MENU_CREAR));
            resultat.Add(new ItemMenu(CommonResources.IconEsborrar.ToBitmap(), "Esborrar seleccionats", MENU_ESBORRAR_SELECCIONATS));
            resultat.Add(new ItemMenu(null, "", "", true));
            resultat.Add(new ItemMenu(CommonResources.IconMail.ToBitmap(), "Enviar correu", MENU_ENVIAR_CORREU));
            return resultat;
        }

        public void ExecuteCommand(string command)
        {
            switch (command)
            {
                case MENU_TANCAR:
                    this.Close();
                    break;
                case MENU_EXECUTAR_CONSULTA:
                    this.ExecutarConsulta();
                    break;
                case MENU_CREAR:
                    this.ObrirDetall(0);
                    break;
                case MENU_ESBORRAR_SELECCIONATS:
                    this.EsborrarSeleccionats();
                    break;
                case MENU_ENVIAR_CORREU:
                    SendMails();
                    break;
            }
        }

        #endregion

        #region Control dels events del formulari
        private void cboProvincia_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Carreguem les poblacions en base al id de provincia seleccionat
            int idProvincia = (int)cboProvincia.SelectedValue;
            FormUtils.CarregaCombo(this.cboPoblacio, WcfUtils.GetPoblacionsByIdProvincia(idProvincia));
        }

        private void btnInteressos_Click(object sender, EventArgs e)
        {
            PopUpSearchCategories categories = new PopUpSearchCategories(this.IdCategories);
            if (categories.ShowDialog(this) == DialogResult.OK)
            {
                this.IdCategories = categories.selectedIds;
                this.txtInteressos.Text = String.Join(", ", categories.selectedNames);
            }
        }

        private void chkSelTot_CheckedChanged(object sender, EventArgs e)
        {
            FormUtils.CheckItemsListView(chkSelTot.Checked, lsvResultats);
        }

        private void lsvResultats_DoubleClick(object sender, EventArgs e)
        {
            if (lsvResultats.SelectedItems.Count > 0)
            {
                int idUsuari = (int)lsvResultats.SelectedItems[0].Tag;
                this.ObrirDetall(idUsuari);
            }
        }

        /// <summary>
        /// Evita que es dispari l'event si no hi ha cap controlador escoltant.
        /// </summary>
        /// <param name="e">Paràmetres de l'event</param>
        protected virtual void OnShowChildForm(ChildFormEventArgs e)
        {
            // Fem una copia temporal del event per a evitar la possibilitat de que 
            // el subscriptor anuli la subscripció quan es dispari l'event
            EventHandler<ChildFormEventArgs> handler = ShowChildForm;
            if (handler != null)
            {
                handler(this, e);
            }
        }
        #endregion

        #region Mètodes privats del formulari
        /// <summary>
        /// Esborra els elements seleccionats de la llista
        /// </summary>
        private void EsborrarSeleccionats()
        {
            UsuarisClient client = null;
            try
            {
                if (lsvResultats.CheckedItems.Count == 0)
                {
                    FormUtils.MissatgeError(CommonResources.SeleccioniElement);
                }
                if (!FormUtils.MissatgeConfirmacio(CommonResources.ConfirmarEliminacio))
                {
                    return;
                }
                IList<int> ids = new List<int>();
                foreach (ListViewItem item in lsvResultats.CheckedItems)
                {
                    ids.Add((int)item.Tag);
                }
                client = WcfFactory.GetUsuarisClient();
                client.EsborrarUsuaris(ids.ToArray<int>());
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsOperacio + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
        }

        /// <summary>
        /// Inicialitza els controls de la pantalla
        /// </summary>
        private void InitializeControls()
        {
            // Carreguem el combo de provincies
            FormUtils.CarregaCombo(this.cboProvincia, WcfUtils.GetProvincies());
            this.titolMain.Image = CommonResources.IconUsuaris.ToBitmap();
        }

        /// <summary>
        /// Executa la consulta de cerca de registres
        /// </summary>
        private void ExecutarConsulta()
        {
            UsuarisClient client = null;
            ItemLlistaUsuaris[] users;
            try
            {
                client = WcfFactory.GetUsuarisClient();
                users = client.ConsultarUsuaris(this.CollectSearchParams());
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregar + "\n" + ex.Message);
                return;
            }
            finally
            {
                if (client != null) { client.Close(); }
            }
            this.CarregarUsuaris(users);
        }

        /// <summary>
        /// Carrega els resultats a la llista
        /// </summary>
        /// <param name="llista">LLista a carregar</param>
        private void CarregarUsuaris(ItemLlistaUsuaris[] llista)
        {
            this.lsvResultats.Items.Clear();
            if (llista.Length == 0)
            {
                FormUtils.MissatgeInformacio(CommonResources.InfoNoRegistres);
                return;
            }
            lsvResultats.BeginUpdate();

            ListViewItem item;
            foreach (ItemLlistaUsuaris usuari in llista)
            {
                item = lsvResultats.Items.Add(String.Empty);
                item.Tag = usuari.IdUsuari;
                item.SubItems.Add(FormatUtils.FormatName(usuari.Nom, usuari.Cognom1, usuari.Cognom2));
                item.SubItems.Add(usuari.Cif);
                item.SubItems.Add(usuari.Email);
                item.SubItems.Add(usuari.NomProvincia);
                item.SubItems.Add(usuari.NomPoblacio);
            }
            lsvResultats.EndUpdate();
        }

        /// <summary>
        /// Recopila els paràmetres de cerca
        /// </summary>
        /// <returns>Paràmetres de cerca</returns>
        private ParamsSearchUsuaris CollectSearchParams()
        {
            ParamsSearchUsuaris result = new ParamsSearchUsuaris();
            result.Nom = txtNom.Text;
            result.Cognom1 = txtCognom1.Text;
            result.Cognom2 = txtCognom2.Text;
            result.Nif = txtNif.Text;
            result.Email = txtEmail.Text;
            result.IdProvincia = (int)cboProvincia.SelectedValue;
            result.IdPoblacio = (int)cboPoblacio.SelectedValue;
            result.Interessos = this.IdCategories;
            return result;
        }

        /// <summary>
        /// Obre el detall d'un usuari
        /// </summary>
        /// <param name="idUsuari">Usuari a obrir</param>
        private void ObrirDetall(int idUsuari)
        {
            if (idUsuari > 0)
            {
                this.OnShowChildForm(new ChildFormEventArgs(new DetailUsuari(idUsuari)));
            }
            else
            {
                this.OnShowChildForm(new ChildFormEventArgs(new DetailUsuari()));
            }
        }

        /// <summary>
        /// Envia un correu electrònic als usuaris seleccionats
        /// </summary>
        private void SendMails()
        {
            // Recuperem les adreces dels destinataris
            if (lsvResultats.CheckedItems.Count <= 0)
            {
                FormUtils.MissatgeError("Com a mínim s'ha de seleccionar un element de la llista");
                return;
            }
            StringBuilder address = new StringBuilder();
            foreach (ListViewItem item in lsvResultats.CheckedItems)
            {
                address.Append(item.SubItems[colMail.Index].Text);
                address.Append(";");
            }
            string[] recipients = address.ToString().Split(new char[] { ';' });
            // Cridem al formulari fill
            this.OnShowChildForm(new ChildFormEventArgs(new EnviarCorreuChild(recipients)));
        }
        #endregion
    }
}
