﻿using Gaudeix.Admin.WCF.Services.Entitats;
using Gaudeix.Admin.WCF.Services.Ofertes;
using Gaudeix.Admin.WCF.Services.TaulesBase;
using Gaudeix.Admin.WCF.Services.Usuaris;
using Gaudeix.Admin.WCF.Services.Compres;
using Gaudeix.Admin.WCF.Services.EMail;
using Gaudeix.Admin.WCF.Services.Estadistiques;
using Gaudeix.Admin.Utils;
using System.ServiceModel;
using System;
using Gaudeix.Admin.Constants;
using Gaudeix.Admin.Infrastructure.Config;

namespace Gaudeix.Admin.Infrastructure.Factory
{
    /// <summary>
    /// Classe d'utilitats per a obtenir els clients de WCF a través del patró Factory
    /// </summary>
    public static class WcfFactory
    {


        /// <summary>
        /// Obté un client per al servei EMail a través del patró Factory
        /// </summary>
        /// <returns>Client per al servei</returns>
        public static EMailClient GetEMailClient()
        {
            EMailClient client = new EMailClient(CommonConstants.ENDPOINT_EMAIL, ConfigManager.GetEndpointEmail());
            client.ClientCredentials.UserName.UserName = ConfigManager.CurrentLoginUser;
            client.ClientCredentials.UserName.Password = ConfigManager.CurrentLoginPassword;
            return client;

        }

        /// <summary>
        /// Obté un client per al servei Entitats a través del patró Factory
        /// </summary>
        /// <returns>Client per al servei</returns>
        public static EntitatsClient GetEntitatsClient()
        {
            EntitatsClient client = new EntitatsClient(CommonConstants.ENDPOINT_ENTITATS, ConfigManager.GetEndpointEntitats());
            client.ClientCredentials.UserName.UserName = ConfigManager.CurrentLoginUser;
            client.ClientCredentials.UserName.Password = ConfigManager.CurrentLoginPassword;
            return client;
        }

        /// <summary>
        /// Obté un client per al servei OfertesClient a través del patró Factory
        /// </summary>
        /// <returns>Client per al servei</returns>
        public static OfertesClient GetOfertesClient()
        {
            OfertesClient client = new OfertesClient(CommonConstants.ENDPOINT_OFERTES, ConfigManager.GetEndpointOfertes());
            client.ClientCredentials.UserName.UserName = ConfigManager.CurrentLoginUser;
            client.ClientCredentials.UserName.Password = ConfigManager.CurrentLoginPassword;
            return client;
        }

        /// <summary>
        /// Obté un client per al servei TaulesBase a través del patró Factory
        /// </summary>
        /// <returns>Client per al servei</returns>
        public static TaulesBaseClient GetTaulesBaseClient()
        {
            TaulesBaseClient client = new TaulesBaseClient(CommonConstants.ENDPOINT_TAULES_BASE, ConfigManager.GetEndpointTaulesBase());
            client.ClientCredentials.UserName.UserName = ConfigManager.CurrentLoginUser;
            client.ClientCredentials.UserName.Password = ConfigManager.CurrentLoginPassword;
            return client;
        }

        /// <summary>
        /// Obté un client per al servei Usuaris a través del patró Factory
        /// </summary>
        /// <returns>Client per al servei</returns>
        public static UsuarisClient GetUsuarisClient()
        {
            UsuarisClient client = new UsuarisClient(CommonConstants.ENDPOINT_USUARIS, ConfigManager.GetEndpointUsuaris());
            client.ClientCredentials.UserName.UserName = ConfigManager.CurrentLoginUser;
            client.ClientCredentials.UserName.Password = ConfigManager.CurrentLoginPassword;
            return client;
        }

        /// <summary>
        /// Obté un client per al servei CompresClient a través del patró Factory
        /// </summary>
        /// <returns>Client per al servei</returns>
        public static CompresClient GetCompresClient()
        {
            CompresClient client = new CompresClient(CommonConstants.ENDPOINT_COMPRES, ConfigManager.GetEndpointCompres());
            client.ClientCredentials.UserName.UserName = ConfigManager.CurrentLoginUser;
            client.ClientCredentials.UserName.Password = ConfigManager.CurrentLoginPassword;
            return client;
        }

        /// <summary>
        /// Obté un client per al servei EstadistiquesClient a través del patró Factory
        /// </summary>
        /// <returns>Client per al servei</returns>
        public static EstadistiquesClient GetEstadistiquesClient()
        {
            EstadistiquesClient client = new EstadistiquesClient(CommonConstants.ENDPOINT_ESTADISTIQUES, ConfigManager.GetEndpointEstadistiques());
            client.ClientCredentials.UserName.UserName = ConfigManager.CurrentLoginUser;
            client.ClientCredentials.UserName.Password = ConfigManager.CurrentLoginPassword;
            return client;
        }

        /// <summary>
        /// Valida si les dades de configuració del servei WCF són correctes o no.
        /// </summary>
        /// <param name="baseUrl">URL Base del servidor WCF</param>
        /// <param name="userName">Nom d'usuari de connexió</param>
        /// <param name="password">Paraula clau de connexió</param>
        /// <returns></returns>
        public static bool CheckCredentials(string baseUrl, string userName, string password)
        {
            bool resultat = false;
            try
            {
                
                // Per a provar la connexió, intentem recuperar la llista de categories
                Uri baseUri = new Uri(baseUrl);

                String url = String.Format("{0}://{1}{2}{3}", baseUri.Scheme, baseUri.Authority, baseUri.LocalPath, CommonConstants.SERVICE_PATH_TAULES_BASE);
                TaulesBaseClient client = new TaulesBaseClient(CommonConstants.ENDPOINT_TAULES_BASE, url);
                client.ClientCredentials.UserName.UserName = userName;
                client.ClientCredentials.UserName.Password = password;
                ItemIdDescripcio[] categories = client.GetLlistaCategories();
                resultat = (categories != null);
            }
            catch (Exception)
            {
                resultat = false;
            }
            return resultat;
        }
    }
}
