﻿using System.Windows.Forms;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.WCF.Services.TaulesBase;

namespace Gaudeix.Admin.Utils
{
    /// <summary>
    /// Classe d'utilitat per a operacions als WinForms
    /// </summary>
    public static class FormUtils
    {
        /// <summary>
        /// Carrega un combobox a partir d'una matriu d'elements ItemIdDescripcio
        /// </summary>
        /// <param name="combo">Combo a carregar</param>
        /// <param name="items">Elements a carregar</param>
        public static void CarregaCombo(ComboBox combo, ItemIdDescripcio[] items)
        {
            combo.DataSource = null;
            combo.Items.Clear();
            combo.ValueMember = "Id";
            combo.DisplayMember = "Descripcio";
            combo.DataSource = items;
            combo.SelectedValue = 0;
            //combo.Items.AddRange(items);
        }

        /// <summary>
        /// Marca o desmarca tots els elements d'un ListView
        /// </summary>
        /// <param name="check">Si s'han de marcar o desmarcar</param>
        /// <param name="listView">Listview sobre el que es treballa</param>
        public static void CheckItemsListView(bool check, ListView listView)
        {
            foreach (ListViewItem listItem in listView.Items)
            {
                listItem.Checked = check;

            }
        }

        /// <summary>
        /// Demana confirmació a l'usuari sobre una acció
        /// </summary>
        /// <param name="missatge">Missatge que es mostra</param>
        /// <returns>Booleà que indica si l'usuari ha confirmat l'operació o no</returns>
        public static bool MissatgeConfirmacio(string missatge)
        {
            return (MessageBox.Show(missatge, CommonResources.ConfirmacioRequerida, MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes);
        }

        /// <summary>
        /// Mostra un missatge d'error a l'usuari
        /// </summary>
        /// <param name="missatge">Missatge que es mostrarà</param>
        public static void MissatgeError(string missatge)
        {
            MessageBox.Show(missatge, CommonResources.ErrorAplicacio,
                MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        /// <summary>
        /// Mostra un missatge per una operació que ha finalitzat correctament
        /// </summary>
        /// <param name="missatge">Missatge que es mostrarà</param>
        public static void MissatgeOperacioOk(string missatge)
        {
            MessageBox.Show(missatge, CommonResources.InfoOperacioOK,
                MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        /// <summary>
        /// Mostra un missatge d'informació
        /// </summary>
        /// <param name="missatge">Missatge que es mostrarà</param>
        public static void MissatgeInformacio(string missatge)
        {
            MessageBox.Show(missatge, CommonResources.Informacio,
                MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        /// <summary>
        /// Mostra un missatge d'alerta
        /// </summary>
        /// <param name="missatge">Missatge que es mostrarà</param>
        public static void MissatgeAlerta(string missatge)
        {
            MessageBox.Show(missatge, CommonResources.WarnAdvertenciaApp,
                MessageBoxButtons.OK, MessageBoxIcon.Warning);
        }
    }
}
