﻿using System;

namespace Gaudeix.Admin.Utils
{
    /// <summary>
    /// Classe d'utilitat per a formatejar tipus de dades
    /// </summary>
    public static class FormatUtils
    {
        /// <summary>
        /// Formateja un import, separant milers i decimals, i afegint símbol de moneda
        /// </summary>
        /// <param name="import">import a formatejar</param>
        /// <returns>Cadena formatejada</returns>
        public static string FormatImport(decimal import)
        {
            return import.ToString("##,##0.00 €");
        }

        /// <summary>
        /// Formateja una data en format dd/MM/yyyy
        /// </summary>
        /// <param name="data">Data a formatejar</param>
        /// <returns>Cadena formatejada</returns>
        public static string FormatData(DateTime data)
        {
            if (data == new DateTime(0))
            {
                return "";
            }
            else
            {
                return data.ToString("dd/MM/yyyy");
            }
        }

        /// <summary>
        /// Formateja un import decimal, separant milers i decimals
        /// </summary>
        /// <param name="import">import a formatejar</param>
        /// <returns>Cadena formatejada</returns>
        public static string FormatDecimal(decimal import)
        {
            return import.ToString("##,##0.00");
        }

        /// <summary>
        /// Formateja un valor enter (Int32), separant milers i decimals
        /// </summary>
        /// <param name="valor">import a formatejar</param>
        /// <returns>Cadena formatejada</returns>
        public static string FormatInt32(Int32 valor)
        {
            return valor.ToString("##,##0");
        }

        /// <summary>
        /// Formateja un nom, aplicant el format 'Cognom1 [Cognom2], Nom'
        /// </summary>
        /// <param name="nom">Nom</param>
        /// <param name="cognom1">Primer cognom</param>
        /// <param name="cognom2">Segon cognom</param>
        /// <returns>Cadena formatejada</returns>
        public static string FormatName(string nom, string cognom1, string cognom2)
        {
            string cadena = "{1}, {0}";
            if (!string.IsNullOrEmpty(cognom2))
            {
                cadena = "{1} {2}, {0} ";
            }
            return String.Format(cadena, nom, cognom1, cognom2);
        }
    }
}
