﻿using System;
using System.Drawing;
using System.IO;

namespace Gaudeix.Admin.Utils
{
    /// <summary>
    /// Classe d'utilitat per a la conversió de tipus de dades
    /// </summary>
    public static class ParseUtils
    {
        #region Mètodes públics
        /// <summary>
        /// Intenta convertir un string en data
        /// </summary>
        /// <param name="date">Data a convertir</param>
        /// <returns>Data convertida, o 'new DateTime(0)' si es produeix un error</returns>
        public static DateTime ParseDateTime(string date)
        {
            DateTime result;
            if (DateTime.TryParse(date, out result))
            {
                return result;
            }
            else
            {
                return new DateTime(0);
            }
        }

        /// <summary>
        /// Converteix un string a decimal
        /// </summary>
        /// <param name="numero">Cadena a convertir</param>
        /// <returns>Valor convertit, o '0' si no s'ha pogut convertir</returns>
        public static decimal ParseDecimal(string numero)
        {
            decimal result = 0;
            if (decimal.TryParse(numero, out result))
            {
                return result;
            }
            else
            {
                return 0;
            }
        }

        /// <summary>
        /// Converteix un string a Int32
        /// </summary>
        /// <param name="numero">Cadena a convertir</param>
        /// <returns>Valor convertit, o '0' si no s'ha pogut convertir</returns>
        public static Int32 ParseInt32(string numero)
        {
            Int32 result = 0;
            if (Int32.TryParse(numero, out result))
            {
                return result;
            }
            else
            {
                return 0;
            }
        }

        /// <summary>
        /// Carrega una imatge a partir d'un array de bytes
        /// </summary>
        /// <param name="byteImage">Array de bytes amb la imatge</param>
        /// <returns>Imatge carregada</returns>
        public static Image ParseImageFromByteArray(byte[] byteImage)
        {
            Image result;
            try
            {
                MemoryStream ms = new MemoryStream(byteImage, 0, byteImage.Length);
                ms.Write(byteImage, 0, byteImage.Length);
                result = Image.FromStream(ms, true);
            }
            catch {
                result = null;
            }
            return result;
        }

        #endregion
    }
}