﻿using System;
using System.ServiceModel;
using Gaudeix.Admin.Infrastructure.Factory;
using Gaudeix.Admin.Resources;
using Gaudeix.Admin.WCF.Services.TaulesBase;

namespace Gaudeix.Admin.Utils
{
    public static class WcfUtils
    {

        /// <summary>
        /// Fa una crida per WCF per a obtenir una llista de províncies, ordenades per codi
        /// </summary>
        /// <returns>Llista de provincies</returns>
        public static ItemIdDescripcio[] GetProvincies()
        {
            TaulesBaseClient client = null;
            ItemIdDescripcio[] result = null;

            try
            {
                // Inicialitzem el combo de provincies
                client = WcfFactory.GetTaulesBaseClient();
                result = client.GetLlistaProvincies();
            }
            catch (FaultException ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregaProvincies + "\n" + ex.Message);
                return new ItemIdDescripcio[] { };
            }
            finally
            {
                if (null != client) { client.Close(); }
            }
            return result;
        }

        /// <summary>
        /// Fa una crida per WCF per a obtenir un llistat de les poblacions que 
        /// pertanyen a una provincia, ordenat per nom
        /// </summary>
        /// <param name="idProvincia">Codi de provincia pel filtre</param>
        /// <returns>Llista de les poblacions que pertanyen a la provincia indicada</returns>
        public static ItemIdDescripcio[] GetPoblacionsByIdProvincia(int idProvincia)
        {
            TaulesBaseClient client = null;
            ItemIdDescripcio[] result = null;

            try
            {
                // Obtenim la llista de poblacions de la provincia
                client = WcfFactory.GetTaulesBaseClient();
                result = client.GetLlistaPoblacionsByProvincia(idProvincia);
            }
            catch (Exception ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorsCarregaPoblacions + "\n" + ex.Message);
                return new ItemIdDescripcio[] { };
            }
            finally
            {
                if (null != client) { client.Close(); }
            }
            return result;
        }

        /// <summary>
        /// Fa una crida per WCF per a obtenir un llistat de les diferents 
        /// categories existents al sistema
        /// </summary>
        /// <returns>Categories del sistema</returns>
        public static ItemIdDescripcio[] GetCategories()
        {
            TaulesBaseClient client = null;
            ItemIdDescripcio[] result = null;
            try
            {
                // Obtenim la llista de categories
                client = WcfFactory.GetTaulesBaseClient();
                result = client.GetLlistaCategories();
            }
            catch (Exception ex)
            {
                FormUtils.MissatgeError(CommonResources.ErrorCarregaCategories + "\n" + ex.Message);
                return new ItemIdDescripcio[] { };
            }
            finally
            {
                if (null != client) { client.Close(); }
            }
            return result;
        }
    }
}
