using System;
using System.Text;
using System.Collections.Generic;
using Gaudeix.Common.Infrastructure.Entity;


namespace Gaudeix.Common.Domain.Entities
{

    public partial class Oferta : BaseEntity
    {

        #region Implementaci de BaseEntity
        /// <summary>
        /// Determina si l'objecte especificat s igual a la instncia actual
        /// </summary>
        /// <param name="obj">Objecte que es comparar amb el nostre</param>
        /// <returns>True si els dos objectes sn iguals, i fals en cas contrari</returns>
        public override bool Equals(object obj)
        {
            if (obj == null || GetType() != obj.GetType())
            {
                // Si l'objecte s null, o si no coincideixen els tipus, retornem fals
                return false;
            }

            // Es retorna true si coincideixen els ID's de les dues classes (propietats inmutables)
            return (obj as Oferta).Id == this.Id;
        }

        /// <summary>
        /// Determina si la instncia de BaseEntity especificada s igual a la instncia actual
        /// </summary>
        /// <param name="obj">Objecte que es comparar amb el nostre</param>
        /// <returns>True si els dos objectes sn iguals, i fals en cas contrari</returns>
        public override bool Equals(BaseEntity other)
        {
            return (this.Equals(other as object));
        }

        /// <summary>
        /// Serveix com a funci de hash per a un objecte determinat.
        /// </summary>
        /// <returns>Hash per a l'objecte actual</returns>
        public override int GetHashCode()
        {
            int hash = 13;
            hash = (hash * 7) + this.Id.GetHashCode();
            return hash;
        }

        /// <summary>
        /// Retorna si l'entitat s nova (true), o si ja existeix a la base de dades (false)
        /// </summary>
        public override bool isNewEntity
        {
            get { return this.Id <= 0; }
        }

        /// <summary>
        /// Obt o estableix la clau primria de l'entitat
        /// </summary>
        public override object PrimaryKey
        {
            get { return this.Id; }
            set { this.Id = (int)value; }
        }
        #endregion

        #region Constructors
        public Oferta()
        {
            ComentarisOferta = new List<ComentariOferta>();
            CompresUsuari = new List<CompraUsuari>();
            FotosOferta = new List<FotoOferta>();
            DataPublicacio = DateTime.Now;
        }

        public Oferta(int idOferta)
            : this()
        {
            this.Id = idOferta;
        }
        #endregion

        #region Propietats de mapeig
        public virtual int Id { get; set; }
        public virtual Empresa Empresa { get; set; }
        public virtual Poblacio Poblacio { get; set; }
        public virtual System.DateTime DataInici { get; set; }
        public virtual System.DateTime DataFi { get; set; }
        public virtual System.DateTime DataPublicacio { get; set; }
        public virtual decimal PreuBase { get; set; }
        public virtual decimal PreuVenda { get; set; }
        public virtual string Titol { get; set; }
        public virtual string Descripcio { get; set; }
        public virtual decimal NotaMitja { get; set; }
        public virtual string DadesResum { get; set; }
        public virtual string DadesAddicionals { get; set; }
        public virtual string DadesLocalitzacio { get; set; }
        public virtual int NumVisites { get; set; }
        public virtual int NumCompres { get; set; }
        public virtual Categoria Categoria { get; set; }
        public virtual IList<ComentariOferta> ComentarisOferta { get; set; }
        public virtual IList<CompraUsuari> CompresUsuari { get; set; }
        public virtual IList<FotoOferta> FotosOferta { get; set; }
        #endregion
    }
}
