using System;
using System.Text;
using System.Collections.Generic;
using Gaudeix.Common.Infrastructure.Entity;


namespace Gaudeix.Common.Domain.Entities
{

    public partial class Poblacio : BaseEntity
    {


        #region Implementaci de BaseEntity
        /// <summary>
        /// Determina si l'objecte especificat s igual a la instncia actual
        /// </summary>
        /// <param name="obj">Objecte que es comparar amb el nostre</param>
        /// <returns>True si els dos objectes sn iguals, i fals en cas contrari</returns>
        public override bool Equals(object obj)
        {
            if (obj == null || GetType() != obj.GetType())
            {
                // Si l'objecte s null, o si no coincideixen els tipus, retornem fals
                return false;
            }

            // Es retorna true si coincideixen els ID's de les dues classes (propietats inmutables)
            return (obj as Poblacio).Id == this.Id;
        }

        /// <summary>
        /// Determina si la instncia de BaseEntity especificada s igual a la instncia actual
        /// </summary>
        /// <param name="obj">Objecte que es comparar amb el nostre</param>
        /// <returns>True si els dos objectes sn iguals, i fals en cas contrari</returns>
        public override bool Equals(BaseEntity other)
        {
            return (this.Equals(other as object));
        }

        /// <summary>
        /// Serveix com a funci de hash per a un objecte determinat.
        /// </summary>
        /// <returns>Hash per a l'objecte actual</returns>
        public override int GetHashCode()
        {
            int hash = 13;
            hash = (hash * 7) + this.Id.GetHashCode();
            return hash;
        }

        /// <summary>
        /// Retorna si l'entitat s nova (true), o si ja existeix a la base de dades (false)
        /// </summary>
        public override bool isNewEntity
        {
            get { return this.Id <= 0; }
        }

        /// <summary>
        /// Obt o estableix la clau primria de l'entitat
        /// </summary>
        public override object PrimaryKey
        {
            get { return this.Id; }
            set { this.Id = (int)value; }
        }
        #endregion

        #region Constructors
        public Poblacio()
        {
            Empreses = new List<Empresa>();
            Ofertes = new List<Oferta>();
            Usuaris = new List<Usuari>();
        }
        public Poblacio(int idPoblacio)
            : this()
        {
            this.Id = idPoblacio;
        }
        #endregion

        #region Propietats de mapeig

        public virtual int Id { get; set; }
        public virtual Provincia Provincia { get; set; }
        public virtual string Nom { get; set; }
        public virtual IList<Empresa> Empreses { get; set; }
        public virtual IList<Oferta> Ofertes { get; set; }
        public virtual IList<Usuari> Usuaris { get; set; }
        #endregion
    }
}
