using System;
using System.Text;
using System.Collections.Generic;
using Gaudeix.Common.Infrastructure.Entity;


namespace Gaudeix.Common.Domain.Entities
{

    public partial class Usuari : BaseEntity
    {
        #region Implementaci de BaseEntity
        /// <summary>
        /// Determina si l'objecte especificat s igual a la instncia actual
        /// </summary>
        /// <param name="obj">Objecte que es comparar amb el nostre</param>
        /// <returns>True si els dos objectes sn iguals, i fals en cas contrari</returns>
        public override bool Equals(object obj)
        {
            if (obj == null || GetType() != obj.GetType())
            {
                // Si l'objecte s null, o si no coincideixen els tipus, retornem fals
                return false;
            }

            // Es retorna true si coincideixen els ID's de les dues classes (propietats inmutables)
            return (obj as Usuari).Id == this.Id;
        }

        /// <summary>
        /// Determina si la instncia de BaseEntity especificada s igual a la instncia actual
        /// </summary>
        /// <param name="obj">Objecte que es comparar amb el nostre</param>
        /// <returns>True si els dos objectes sn iguals, i fals en cas contrari</returns>
        public override bool Equals(BaseEntity other)
        {
            return (this.Equals(other as object));
        }

        /// <summary>
        /// Serveix com a funci de hash per a un objecte determinat.
        /// </summary>
        /// <returns>Hash per a l'objecte actual</returns>
        public override int GetHashCode()
        {
            int hash = 13;
            hash = (hash * 7) + this.Id.GetHashCode();
            return hash;
        }

        /// <summary>
        /// Retorna si l'entitat s nova (true), o si ja existeix a la base de dades (false)
        /// </summary>
        public override bool isNewEntity
        {
            get { return this.Id <= 0; }
        }

        /// <summary>
        /// Obt o estableix la clau primria de l'entitat
        /// </summary>
        public override object PrimaryKey
        {
            get { return this.Id; }
            set { this.Id = (int)value; }
        }
        #endregion

        #region Constructors
        public Usuari()
        {
            CategoriesUsuari = new List<CategoriaUsuari>();
            ComentarisOfertes = new List<ComentariOferta>();
            CompresUsuari = new List<CompraUsuari>();
            DataAlta = DateTime.Now;
        }

        public Usuari(int idUsuari)
            : this()
        {
            this.Id = idUsuari;
        }
        #endregion

        #region Propietats de mapeig
        public virtual int Id { get; set; }
        public virtual Poblacio Poblacio { get; set; }
        public virtual string Nom { get; set; }
        public virtual string Cognom1 { get; set; }
        public virtual string Cognom2 { get; set; }
        public virtual string Nif { get; set; }
        public virtual string Email { get; set; }
        public virtual string Adreca { get; set; }
        public virtual string CodiPostal { get; set; }
        public virtual System.DateTime DataNaixement { get; set; }
        public virtual System.DateTime DataAlta { get; set; }
        public virtual string LoginUsuari { get; set; }
        public virtual string LoginPassword { get; set; }
        public virtual string PreguntaClau { get; set; }
        public virtual string RespostaClau { get; set; }
        public virtual bool MailOfertes { get; set; }
        public virtual IList<CategoriaUsuari> CategoriesUsuari { get; set; }
        public virtual IList<ComentariOferta> ComentarisOfertes { get; set; }
        public virtual IList<CompraUsuari> CompresUsuari { get; set; }
        #endregion
    }
}
