﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Gaudeix.Common.Exceptions
{
    /// <summary>
    /// Excepció per a encapsular tots els errors produïts a la capa de negoci
    /// </summary>
    public class GaudeixBusinessException : System.Exception
    {
        private string missatge;

        /// <summary>
        /// Retorna el missatge associat a una excepció
        /// </summary>
        public override string Message
        {
            get { return this.missatge; }
        }

        /// <summary>
        /// Inicialitza una nova instancia de la classe.
        /// </summary>
        /// <param name="message">Missatge d'error</param>
        public GaudeixBusinessException(string missatge)
        {
            this.missatge = missatge;
        }

        /// <summary>
        /// Inicialitza una nova instancia de la classe, inicialitzant-la amb un missatge d'error 
        /// i una excepció interna que representa la causa de l'exepció
        /// </summary>
        /// <param name="missatge">Missatge d'error que explica el motiu de l'excepció</param>
        /// <param name="innerException">Excepció original produïda</param>
        public GaudeixBusinessException(string missatge, Exception innerException)
            : base(missatge, innerException)
        {
            this.missatge = missatge;
            if (innerException is GaudeixDaoException)
            {
                this.missatge = innerException.Message;
            }
        }

        /// <summary>
        /// Inicialitza una nova instancia de la classe, inicialitzant-la amb un missatge d'error 
        /// i una excepció interna que representa la causa de l'exepció
        /// </summary>
        /// <param name="missatge">Missatge d'error que explica el motiu de l'excepció</param>
        /// <param name="innerException">Excepció original produïda</param>
        public GaudeixBusinessException(GaudeixDaoException innerException)
            : base(innerException.Message, innerException)
        {
            this.missatge = innerException.Message;
        }
    }
}
