﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;

namespace Gaudeix.Common.Infrastructure.Entity
{
    /// <summary>
    /// Superclasse abstracta de la que deriven totes les entitats
    /// </summary>
    public abstract class BaseEntity : IEquatable<BaseEntity>
    {
        /// <summary>
        /// Determina si l'objecte especificat és igual a la instància actual
        /// </summary>
        /// <param name="obj">Objecte que es compararà amb el nostre</param>
        /// <returns>True si els dos objectes són iguals, i fals en cas contrari</returns>
        public abstract override bool Equals(object obj);

        /// <summary>
        /// Determina si la instància de BaseEntity especificada és igual a la instància actual
        /// </summary>
        /// <param name="obj">Objecte que es compararà amb el nostre</param>
        /// <returns>True si els dos objectes són iguals, i fals en cas contrari</returns>
        public abstract bool Equals(BaseEntity other);

        /// <summary>
        /// Serveix com a funció de hash per a un objecte determinat.
        /// </summary>
        /// <returns>Hash per a l'objecte actual</returns>
        public abstract override int GetHashCode();

        /// <summary>
        /// Retorna si l'entitat és nova (true), o si ja existeix a la base de dades (false)
        /// </summary>
        public abstract Boolean isNewEntity { get; }

        /// <summary>
        /// Obté o estableix la clau primària de l'entitat
        /// </summary>
        public abstract object PrimaryKey { get; set; }


    }
}
