﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Infrastructure.Dao;
using Gaudeix.Common.Models.Compra;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Models.Users;
using Gaudeix.Common.Models.Common;

namespace Gaudeix.Common.Interfaces.Dao
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre compres d'usuari per a la capa de dades
    /// </summary>
    public interface ICompraUsuariDao : IBaseDao<CompraUsuari, int>
    {
        #region Mètodes a implementar
        /// <summary>
        /// Consulta les compres que coincideixen amb els paràmetres de cerca
        /// </summary>
        /// <param name="parametres">Paràmetres de cerca</param>
        /// <returns>Compres que coincideixen amb els paràmtres de cerca</returns>
        IList<ItemLlistaCompres> ConsultarCompres(ParamsSearchCompres parametres);

        /// <summary>
        /// Guarda una compra a la BD
        /// </summary>
        /// <param name="idArticle">Article comprat</param>
        /// <param name="idUsuari">Usuari que fa la compra</param>
        /// <returns>ID del nou registre creat</returns>
        int GuardarCompra(int idArticle, int idUsuari);

        /// <summary>
        /// Obté un llistat de totes les compres de l'usuari
        /// </summary>
        /// <param name="idUsuari"></param>
        /// <returns></returns>
        IList<ItemCompresUsuari> GetCompresUsuari(int idUsuari);

        /// <summary>
        /// Obté un llistat de data-valor de les vendes dels darrers set dies
        /// </summary>
        /// <returns>Llistat de vendes dels darrers set dies</returns>
        IList<ItemDataValor> GetEstadisticaVendes();

        /// <summary>
        /// Obté un llistat de data-valor dels beneficis dels darrers set dies
        /// </summary>
        /// <returns>Llistat de beneficis dels darrers set dies</returns>
        IList<ItemDataValor> GetEstadisticaBeneficis();
        #endregion
    }
}
