﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Infrastructure.Dao;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Models.Empresa;


namespace Gaudeix.Common.Interfaces.Dao
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre Empreses per a la capa de dades
    /// </summary>
    public interface IEmpresaDao : IBaseDao<Empresa, int>
    {
        #region Mètodes a implementar
        /// <summary>
        /// Retorna un llistat de les entitats que compleixen els paràmetres de cerca.
        /// </summary>
        /// <param name="parametres">Paràmetres de cerca</param>
        /// <exception cref="GaudeixDaoException">En cas d'error en l'accés a la BD</exception>
        IList<ItemLlistaEmpreses> ConsultarEntitats(ParamsSearchEmpreses parametres);

        /// <summary>
        /// Obté el detall d'una empresa a partir del seu ID
        /// </summary>
        /// <param name="idEmpresa">ID de l'empresa a cercar</param>
        /// <returns>Dades de l'empresa</returns>
        /// <exception cref="GaudeixDaoException">En cas d'error en l'accés a la BD</exception>
        DetallEmpresa GetDetallEmpresa(int idEmpresa);

        /// <summary>
        /// Obté un llistat de les diferents ofertes d'una empresa en concret
        /// </summary>
        /// <param name="idEmpresa">Codi de l'empresa</param>
        /// <returns>Llistat d'ofertes de l'empresa</returns>
        /// <exception cref="GaudeixDaoException">En cas d'error en l'accés a la BD</exception>
        IList<ItemOfertesEmpresa> GetOfertesEmpresa(int idEmpresa);

        /// <summary>
        /// Obté un llistat de tots els correus electrònics de les empreses registrades
        /// </summary>
        /// <returns>Llista de correus electrònics</returns>
        IList<string> GetAllEmailsFromEmpreses();
        #endregion
    }
}
