﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Models.Oferta;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Infrastructure.Dao;
using Gaudeix.Common.Models.Browse;
using Gaudeix.Common.Models.Common;

namespace Gaudeix.Common.Interfaces.Dao
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre Ofertes per a la capa de dades
    /// </summary>
    public interface IOfertaDao : IBaseDao<Oferta, int>
    {
        #region Mètodes a implementar
        /// <summary>
        /// Retorna un llistat de les ofertes que compleixen els paràmetres de cerca.
        /// </summary>
        /// <param name="parametres">Paràmetres de cerca</param>
        /// <returns>Llista d'ofertes que compleixen amb els paràmetres de cerca</returns>
        /// <exception cref="GaudeixDaoException">En cas d'error durant l'execució del mètode</exception>
        IList<ItemLlistaOfertes> ConsultarOfertes(ParamsSearchOfertes parametres);

        /// <summary>
        /// Retorna un llistat de les ofertes que compleixen els paràmetres de cerca, però fent servir paginació de registres
        /// </summary>
        /// <param name="parametres">Paràmetres de cerca</param>
        /// <param name="numPlana">Número de plana a recuperar</param>
        /// <param name="numRegsPlana">Número de registres per plana</param>
        /// <returns>Llistat de (numRegsPlana + 1) registres, per tal de que 
        /// es pugui activar o no el botó de següent (si es retorna 
        /// (numRegsPlana + 1) registres, es pot mostrar el botó de següent).</returns>
        IList<ItemLlistaOfertes> ConsultarOfertesPaginat(ParamsSearchOfertes parametres,
            int numPlana, int numRegsPlana);

        /// <summary>
        /// Obté el detall d'una oferta a partir de la seva clau primaria
        /// </summary>
        /// <param name="idEmpresa">Clau primària de la oferta</param>
        /// <returns>Detall de la oferta</returns>
        /// <exception cref="GaudeixDaoException">En cas d'error durant l'execució del mètode</exception>
        DetallOfertaWcf GetDetallOfertaForWCF(int idOferta);

        /// <summary>
        /// Obté el detall d'una oferta a partir de la seva clau primaria per a mostrar-la a la web
        /// </summary>
        /// <param name="idEmpresa">Clau primària de la oferta</param>
        /// <returns>Detall de la oferta</returns>
        /// <exception cref="GaudeixDaoException">En cas d'error durant l'execució del mètode</exception>
        DetallOfertaModel GetDetallOfertaForWeb(int idOferta);

        /// <summary>
        /// Actualitza les estadístiques d'una oferta determinada
        /// </summary>
        /// <param name="idOferta">Codi de la oferta</param>
        /// <returns></returns>
        int ActualitzarEstadistiques(int idOferta);

        /// <summary>
        /// Incrementa en una unitat el número de visites d'una oferta
        /// </summary>
        /// <param name="idOferta">Codi de la oferta</param>
        void AfegirVisita(int idOferta);

        /// <summary>
        /// Incrementa en una unitat el número de compres d'una oferta
        /// </summary>
        /// <param name="idOferta">Codi de la oferta</param>
        void AfegirCompra(int idOferta);

        /// <summary>
        /// Obté un llistat de data-valor de les publicacions d'ofertes dels darrers set dies
        /// </summary>
        /// <returns>Llistat d'ofertes publicades dels darrers set dies</returns>
        IList<ItemDataValor> GetEstadisticaPublicacions();

        /// <summary>
        /// Recupera les darreres ofertes afegides a la categoria indicada, durant la darrera setmana
        /// </summary>
        /// <param name="idCategoria">Categoria de cerca</param>
        /// <returns>Llista d'ofertes coincidents</returns>
        IList<Oferta> GetTopOfertes(int idCategoria);
        #endregion


    }
}
