﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Infrastructure.Dao;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Models.Users;
using Gaudeix.Common.Models.Common;

namespace Gaudeix.Common.Interfaces.Dao
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre usuaris per a la capa de dades
    /// </summary>
    public interface IUsuariDao : IBaseDao<Usuari, int>
    {
        #region Mètodes a implementar
        /// <summary>
        /// Obté les dades d'un usuari a partir del seu codi d'usuari
        /// </summary>
        /// <param name="username">Codi d'usuari</param>
        /// <returns>Dades de l'usuari</returns>
        /// <exception cref="GaudeixDaoException">En cas d'error en l'accés a la BD</exception>
        Usuari GetByUsername(String username);

        /// <summary>
        /// Obté les dades d'un usuari a partir del seu NIF
        /// </summary>
        /// <param name="nif">NIF de l'usuari</param>
        /// <returns>Dades de l'usuari</returns>
        /// <exception cref="GaudeixDaoException">En cas d'error en l'accés a la BD</exception>
        Usuari GetByNif(String nif);

        /// <summary>
        /// Obté la llista de les ofertes que compleixen els paràmetres de cerca
        /// </summary>
        /// <param name="parametres">Paràmetres de cerca</param>
        /// <returns>Ofertes que coincideixen amb els paràmetres de cerca</returns>
        IList<ItemLlistaUsuaris> ConsultarOfertes(ParamsSearchUsuaris parametres);

        /// <summary>
        /// Obté el detall de l'usuari a partir del seu ID de BD
        /// </summary>
        /// <param name="idUsuari">ID a cercar</param>
        /// <returns>Detall de l'usuari</returns>
        DetallUsuari GetDetallUsuari(int idUsuari);

        /// <summary>
        /// Obté un llistat de tots els correus electrònics dels usuaris registrats
        /// </summary>
        /// <returns>Llista de correus electrònics</returns>
        IList<String> GetAllEmailsFromUsers();

        /// <summary>
        /// Obté un llistat de data-valor dels registres d'usuari dels darrers set dies
        /// </summary>
        /// <returns>Llistat de registres d'usuari dels darrers set dies</returns>
        IList<ItemDataValor> GetEstadisticaRegistres();

    /// <summary>
    /// Recupera un llistat d'usuaris que tenen activada una categoria determinada, 
    /// i que volen rebre correus electrònics
    /// </summary>
    /// <param name="idCategoria">Categoria de filtre</param>
    /// <returns>Llista d'usuaris que compleixen els requisits</returns>
        IList<Usuari> GetMailUsersByIdCategoria(int idCategoria);
        #endregion
    }
}
