﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Infrastructure.Manager;
using Gaudeix.Common.Models.Compra;
using Gaudeix.Common.Models.Users;

namespace Gaudeix.Common.Interfaces.Manager
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre compres d'usuari per a la capa de negoci
    /// </summary>
    public interface ICompraUsuariManager : IBaseManager
    {
        #region Mètodes a implementar
        /// <summary>
        /// Retorna un llistat de les compres que compleixen els paràmetres de cerca.
        /// </summary>
        /// <returns>Llista de compres que compleixen amb els paràmetres de cerca</returns>
        /// <exception cref="GaudeixBusinessException">En cas d'error durant l'execució del mètode</exception>
        IList<ItemLlistaCompres> ConsultarCompres(ParamsSearchCompres parametres);

        /// <summary>
        /// Realitza la compra d'un article
        /// </summary>
        /// <param name="idArticle">Article adquirit</param>
        /// <param name="username">Nom d'usuari</param>
        /// <param name="numTarjaCredit">Tarja de crèdit</param>
        /// <param name="linkArticle">URL de l'article</param>
        /// <param name="codiValidacio">Codi de validació de la tarja de crèdit</param>
        /// <returns>ID de la compra</returns>
        int ComprarArticle(int idArticle, string username, string numTarjaCredit, string codiValidacio, string linkArticle);

        #endregion

    }
}
