﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Infrastructure.Manager;
using Gaudeix.Common.Models.Browse;

namespace Gaudeix.Common.Interfaces.Manager
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre correus electrònics per a la capa de negoci
    /// </summary>
    public interface ICuaCorreuManager : IBaseManager
    {
        #region Mètodes a implementar

        /// <summary>
        /// Encua un correu electrònic per a que sigui processat pel procés d'enviament de correu
        /// </summary>
        /// <param name="destinatari">email del destinatari</param>
        /// <param name="titol">Titol del correu</param>
        /// <param name="message">Missatge del correu</param>
        void EnqueueMail(string destinatari, string titol, string message);

        /// <summary>
        /// Encua un correu de recomanació d'oferta a tercers
        /// </summary>
        /// <param name="model">Dades de la recomanació</param>
        /// <param name="linkOferta">Link de la oferta</param>
        void EnqueueMailRecommend(RecommendPopUpModel model, string linkOferta);

        /// <summary>
        /// Encua un correu de confirmació de compra per a l'usuari
        /// </summary>
        /// <param name="idCompra">Codi de la compra</param>
        /// <param name="linkOferta">Link de la oferta</param>
        void EnqueueMailCompraUsuari(int idCompra, string linkOferta);

        /// <summary>
        /// Encua un correu de confirmació de compra per a l'empresa
        /// </summary>
        /// <param name="idCompra">Codi de la compra</param>
        /// <param name="linkOferta">Link de la oferta</param>
        void EnqueueMailCompraEmpresa(int idCompra, string linkOferta);

        /// <summary>
        /// Encua un correu de benvinguda al portal per a un nou usuari
        /// </summary>
        /// <param name="idUsuari">Codi de l'usuari</param>
        void EnqueueMailBenvinguda(int idUsuari);

        /// <summary>
        /// Processa la cua de correus pendents
        /// </summary>
        void ProcessMailQueue();
      
        /// <summary>
        /// Procés d'enviament de correus d'ofertes
        /// </summary>
        void ProcessMailOfertes();
        #endregion

    }
}
