﻿using System.Collections.Generic;
using Gaudeix.Common.Models.Empresa;
using Gaudeix.Common.Infrastructure.Manager;

namespace Gaudeix.Common.Interfaces.Manager
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre empreses per a la capa de negoci
    /// </summary>
    public interface IEmpresaManager : IBaseManager
    {
        #region Mètodes a implementar
        /// <summary>
        /// Guarda una empresa, existent o nova, a la base de dades
        /// </summary>
        /// <param name="empresa">Empresa a guardar</param>
        /// <returns>Clau primària del registre guardat o actualitzat</returns>
        /// <exception cref="GaudeixBusinessException">En cas d'error durant l'execució del mètode</exception>
        int GuardarEmpresa(DetallEmpresa empresa);

        /// <summary>
        /// Obté una llista de les empreses que coincideixen amb els paràmetres de cerca. 
        /// Tot i que els paràmetres de cerca són opcionals, s'ha d'informar algun d'ells.
        /// </summary>
        ///<param name="parametres">Parametres de cerca</param>
        /// <returns>Llista d'empreses que coincideixen amb els paràmetres de cerca</returns>
        /// <exception cref="GaudeixBusinessException">En cas d'error durant l'execució del mètode</exception>
        IList<ItemLlistaEmpreses> ConsultarEntitats(ParamsSearchEmpreses parametres);

        /// <summary>
        /// Obté el detall d'una empresa a partir de la seva clau primària
        /// </summary>
        /// <param name="idEmpresa">Clau primària de l'empresa</param>
        /// <returns>Detall de l'empresa</returns>
        /// <exception cref="GaudeixBusinessException">En cas d'error durant l'execució del mètode</exception>
        DetallEmpresa GetDetallEmpresa(int idEmpresa);

        /// <summary>
        /// Obté un llistat de tots els correus electrònics de les empreses registrades
        /// </summary>
        /// <returns>Llista de correus electrònics</returns>
        IList<string> GetAllEmailsFromEmpreses();

        /// <summary>
        /// Esborra les empreses passades com a paràmetres
        /// </summary>
        /// <param name="idEmpreses">ID's de empreses a esborrar</param>
        void EsborrarEmpreses(int[] idEmpreses);
        #endregion
    }
}
