﻿using System.Collections.Generic;
using Gaudeix.Common.Infrastructure.Manager;
using Gaudeix.Common.Models.Common;

namespace Gaudeix.Common.Interfaces.Manager
{
    /// <summary>
    /// Interficie de declaracio d'operacions sobre taules base per la capa de negoci
    /// </summary>
    public interface ITaulesBaseManager : IBaseManager
    {
        #region Mètodes a implementar
        /// <summary>
        /// Obté la llsita de les categories del sistema
        /// </summary>
        /// <returns>Categories ordenades per nom ascendent</returns>
        IList<ItemIdDescripcio> GetCategories();

        /// <summary>
        /// Obté un llistat de les poblacions que pertanyen a una provincia determinada
        /// </summary>
        /// <param name="idProvincia">Codi de la provincia a cercar</param>
        /// <returns>Llista de les poblacions que pertanyen a la provincia indicada</returns>
        /// <exception cref="GaudeixBusinessException">En cas d'error durant l'execució del mètode</exception>
        IList<ItemIdDescripcio> GetPoblacionsByIdProvincia(int idProvincia);

        /// <summary>
        /// Recupera totes les provincies donades d'alta a la base de dades
        /// </summary>
        /// <returns>Llista de provincies, ordenada per nom ascendent</returns>
        /// <exception cref="GaudeixBusinessException">En cas d'error durant el procés del mètode</exception>
        IList<ItemIdDescripcio> GetProvincies();
        #endregion
    }
}
