﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Web.Mvc;
using Gaudeix.Common.Resources;
using Gaudeix.Common.Models.Common;
using System;
using Gaudeix.Common.Models.Profile;

namespace Gaudeix.Common.Models.Account
{
    /// <summary>
    /// Model per a donar suport al procés de registre al portal
    /// </summary>
    public class RegisterModel
    {
        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Nom", ResourceType = typeof(CommonFields))]
        [StringLength(20)]
        public string Nom { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Cognom1", ResourceType = typeof(CommonFields))]
        [StringLength(20)]
        public string Cognom1 { get; set; }

        [Display(Name = "Cognom2", ResourceType = typeof(CommonFields))]
        [StringLength(20)]
        public string Cognom2 { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Nif", ResourceType = typeof(CommonFields))]
        [StringLength(9)]
        public string Nif { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "EMail", ResourceType = typeof(CommonFields))]
        [DataType(DataType.EmailAddress)]
        [StringLength(80)]
        public string Email { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Adreca", ResourceType = typeof(CommonFields))]
        [StringLength(100)]
        public string Adreca { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Provincia", ResourceType = typeof(CommonFields))]
        public int idProvincia { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Poblacio", ResourceType = typeof(CommonFields))]
        public int idPoblacio { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "CodiPostal", ResourceType = typeof(CommonFields))]
        [StringLength(5)]
        public string CodiPostal { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "DataNaixement", ResourceType = typeof(CommonFields))]
        [DataType(DataType.Date)]
        public DateTime DataNaixement { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "LoginUsername", ResourceType = typeof(CommonFields))]
        [StringLength(12)]
        public string UsuariLogin { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [StringLength(30, ErrorMessageResourceName = "NumCaracters", ErrorMessageResourceType = typeof(CommonErrors), MinimumLength = 6)]
        [DataType(DataType.Password)]
        [Display(Name = "LoginPassword", ResourceType = typeof(CommonFields))]
        public string UsuariPassword { get; set; }

        [DataType(DataType.Password)]
        [Display(Name = "LoginConfirmPassword", ResourceType = typeof(CommonFields))]
        [Compare("UsuariPassword", ErrorMessageResourceName="ParaulesClauDiferents", ErrorMessageResourceType = typeof(CommonErrors))]
        public string ConfirmUsuariPassword { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name="PreguntaSeguretat", ResourceType=typeof(CommonFields))]
        public string PreguntaClau { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "RespostaSeguretat", ResourceType = typeof(CommonFields))]
        public string RespostaClau{ get; set; }

        [Display(Name = "RebreCorreuOfertes", ResourceType = typeof(CommonFields))]
        public bool MailOfertes{ get; set; }

        public IList<ItemIdDescripcio> LlistaProvincies { get; set; }

        public IList<ItemIdDescripcio> LlistaPoblacions { get; set; }

        public IList<ItemLlistaCategories> LlistaCategories { get; set; }

        public RegisterModel()
        {
            this.LlistaPoblacions = new List<ItemIdDescripcio>();
            this.LlistaProvincies = new List<ItemIdDescripcio>();
            this.LlistaCategories = new List<ItemLlistaCategories>();
        }
    }
}
