﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Runtime.Serialization;

namespace Gaudeix.Common.Models.Compra
{
    /// <summary>
    /// Classe que conté els paràmtres per a la cerca de compres d'usuari
    /// </summary>
    [DataContract]
    public class ParamsSearchCompres
    {
        #region Propietats públiques
        [DataMember]
        public int IdEmpresa { get; set; }

        [DataMember]
        public string Titol { get; set; }

        [DataMember]
        public decimal PreuBaseDesDe { get; set; }

        [DataMember]
        public decimal PreuBaseFins { get; set; }

        [DataMember]
        public decimal PreuVendaDesDe { get; set; }

        [DataMember]
        public decimal PreuVendaFins { get; set; }

        [DataMember]
        public DateTime DataIniciDesDe { get; set; }

        [DataMember]
        public DateTime DataIniciFins { get; set; }

        [DataMember]
        public DateTime DataFiDesDe { get; set; }

        [DataMember]
        public DateTime DataFiFins { get; set; }

        [DataMember]
        public int IdProvincia { get; set; }

        [DataMember]
        public int IdPoblacio { get; set; }

        [DataMember]
        public int[] Categories { get; set; }

        #endregion

        #region Mètodes públics
        /// <summary>
        /// Obté el número de paràmetres informats
        /// </summary>
        public int NumParametresInformats
        {
            get
            {
                int numParams = 0;
                if (IdEmpresa > 0) { numParams++; }
                if (String.IsNullOrEmpty(this.Titol)) { numParams++; }
                if (PreuBaseDesDe > 0) { numParams++; }
                if (PreuBaseFins > 0) { numParams++; }
                if (PreuVendaDesDe > 0) { numParams++; }
                if (PreuVendaFins > 0) { numParams++; }
                if (DataIniciDesDe != new DateTime(0)) { numParams++; }
                if (DataIniciFins != new DateTime(0)) { numParams++; }
                if (DataFiDesDe != new DateTime(0)) { numParams++; }
                if (DataFiFins != new DateTime(0)) { numParams++; }
                if (IdProvincia <= 0) { numParams++; }
                if (IdPoblacio <= 0) { numParams++; }
                if ((Categories != null) && (Categories.Count() > 0)) { numParams++; }
                return numParams;
            }
        }
        #endregion
    }
}
