﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using Gaudeix.Common.Models.Common;
using Gaudeix.Common.Models.Users;
using Gaudeix.Common.Resources;

namespace Gaudeix.Common.Models.Profile
{
    public class ProfileModel
    {
        #region Propietats públiques de la classe
        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Nom", ResourceType = typeof(CommonFields))]
        [StringLength(20)]
        public string Nom { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Cognom1", ResourceType = typeof(CommonFields))]
        [StringLength(20)]
        public string Cognom1 { get; set; }

        [Display(Name = "Cognom2", ResourceType = typeof(CommonFields))]
        [StringLength(20)]
        public string Cognom2 { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Nif", ResourceType = typeof(CommonFields))]
        [StringLength(9)]
        public string Nif { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "EMail", ResourceType = typeof(CommonFields))]
        [DataType(DataType.EmailAddress)]
        [StringLength(80)]
        public string Email { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Adreca", ResourceType = typeof(CommonFields))]
        [StringLength(100)]
        public string Adreca { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Provincia", ResourceType = typeof(CommonFields))]
        public int idProvincia { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "Poblacio", ResourceType = typeof(CommonFields))]
        public int idPoblacio { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "CodiPostal", ResourceType = typeof(CommonFields))]
        [StringLength(5)]
        public string CodiPostal { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [Display(Name = "DataNaixement", ResourceType = typeof(CommonFields))]
        [DataType(DataType.Date)]
        public DateTime DataNaixement { get; set; }

        [Display(Name = "LoginUsername", ResourceType = typeof(CommonFields))]
        [StringLength(12)]
        public string UsuariLogin { get; set; }

        //[Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        //[StringLength(30, ErrorMessage = "El número de caràcters de {0} ha de ser de {2} com a mínim.", MinimumLength = 6)]
        [DataType(DataType.Password)]
        //[Display(Name = "NewPassword", ResourceType = typeof(CommonFields))]
        public string UsuariPassword { get; set; }

        [DataType(DataType.Password)]
        //[Display(Name = "ConfirmNewPassword", ResourceType = typeof(CommonFields))]
        //[Compare("UsuariPassword", ErrorMessage = "Les paraules clau no coincideixen.")]
        public string ConfirmUsuariPassword { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [StringLength(80)]
        [Display(Name = "PreguntaSeguretat", ResourceType = typeof(CommonFields))]
        public string PreguntaClau { get; set; }

        [Required(ErrorMessageResourceName = "CampObligatori", ErrorMessageResourceType = typeof(CommonErrors))]
        [StringLength(50)]
        [Display(Name = "RespostaSeguretat", ResourceType = typeof(CommonFields))]
        public string RespostaClau { get; set; }

        [Display(Name = "RebreCorreuOfertes", ResourceType = typeof(CommonFields))]
        public bool MailOfertes { get; set; }

        public IList<ItemIdDescripcio> LlistaProvincies { get; set; }

        public IList<ItemIdDescripcio> LlistaPoblacions { get; set; }

        public IList<ItemCompresUsuari> LlistaCompres { get; set; }

        public IList<ItemLlistaCategories> LlistaCategories { get; set; }

        public string InfoMessage { get; set; }
#endregion

        #region Constructors
        public ProfileModel()
        {
            this.LlistaPoblacions = new List<ItemIdDescripcio>();
            this.LlistaProvincies = new List<ItemIdDescripcio>();
            this.LlistaCompres = new List<ItemCompresUsuari>();
            this.LlistaCategories = new List<ItemLlistaCategories>();
        }

        public ProfileModel(string nom, string cognom1, string cognom2, string nif,
                    string email, string adreca, int idProvincia, int idPoblacio,
                    string codiPostal, DateTime dataNaixement, string usuariLogin,
                    string usuariPassword, string confirmUsuariPassword,
                    string preguntaClau, string respostaClau, bool mailOfertes)
            : this()
        {
            this.Nom = nom;
            this.Cognom1 = cognom1;
            this.Cognom2 = cognom2;
            this.Nif = nif;
            this.Email = email;
            this.Adreca = adreca;
            this.idProvincia = idProvincia;
            this.idPoblacio = idPoblacio;
            this.CodiPostal = codiPostal;
            this.DataNaixement = dataNaixement;
            this.UsuariLogin = usuariLogin;
            this.UsuariPassword = UsuariPassword;
            this.ConfirmUsuariPassword = ConfirmUsuariPassword;
            this.PreguntaClau = preguntaClau;
            this.RespostaClau = respostaClau;
            this.MailOfertes = mailOfertes;
        }



        #endregion

    }
}