﻿using System;

namespace Gaudeix.Common.Utils
{
    /// <summary>
    /// Classe amb mètodes d'ajut per a formatejar camps
    /// </summary>
    public static class FormatUtils
    {
        /// <summary>
        /// Formateja un número, separant els milers i afegint dos decimals i el símbol de moneda
        /// </summary>
        /// <param name="import">Import a formatejar</param>
        /// <returns>Import formatejat</returns>
        public static string FormatImport(decimal import)
        {
            return import.ToString("##,##0.00 €");
        }

        /// <summary>
        /// Formateja una data en format dd/MM/yyyy
        /// </summary>
        /// <param name="data">Data a formatejar</param>
        /// <returns>Cadena amb la data si es pot formatejar, o cadena buida 
        /// si la data és igual a DateTime(0)</returns>
        public static string FormatData(DateTime data)
        {
            if (data == new DateTime(0))
            {
                return "";
            }
            else
            {
                return data.ToString("dd/MM/yyyy");
            }
        }

        /// <summary>
        /// Formateja un número, separant els milers i afegint dos decimals
        /// </summary>
        /// <param name="import">Import a formatejar</param>
        /// <returns>Import formatejat</returns>
        public static string FormatDecimal(decimal import)
        {
            return import.ToString("##,##0.00");
        }

        /// <summary>
        /// Formateja un nom en format 'Cognoms, Nom'
        /// </summary>
        /// <param name="nom">Cadena amb el nom</param>
        /// <param name="cognom1">Cadena amb el primer cognom</param>
        /// <param name="cognom2">(Opcional) Cadena amb el segon cognom</param>
        /// <returns>Cadena formada per Cognom1 [Cognom2], Nom</returns>
        public static string FormatName(string nom, string cognom1, string cognom2)
        {
            string cadena = "{1}, {0}";
            if (!string.IsNullOrEmpty(cognom2))
            {
                cadena = "{1} {2}, {0}";
            }
            return String.Format(cadena, nom, cognom1, cognom2);
        }


        /// <summary>
        /// Formateja un nom en format 'Nom Cognoms'
        /// </summary>
        /// <param name="nom">Cadena amb el nom</param>
        /// <param name="cognom1">Cadena amb el primer cognom</param>
        /// <param name="cognom2">(Opcional) Cadena amb el segon cognom</param>
        /// <returns>Cadena formada per Cognom1 [Cognom2], Nom</returns>
        public static string FormatNameSurname(string nom, string cognom1, string cognom2)
        {
            string cadena = "{0} {1} {2}";
            return String.Format(cadena, nom, cognom1, cognom2);
        }
    }
}
