﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Gaudeix.Common.Utils
{
    /// <summary>
    /// Classe amb mètodes d'ajut per a convertir tipus de dades
    /// </summary>
    public static class ParseUtils
    {
        /// <summary>
        /// Intenta convertir una cadena de text a data
        /// </summary>
        /// <param name="date">Cadena a convertir</param>
        /// <returns>DateTime convertida, o new DateTime(0) si no pot convertir-ho</returns>
        public static DateTime ParseDateTime(string date)
        {
            DateTime result;
            if (DateTime.TryParse(date, out result))
            {
                return result;
            }
            else
            {
                return new DateTime(0);
            }
        }

        /// <summary>
        /// Intenta convertir una cadena de text a decimal
        /// </summary>
        /// <param name="numero">Cadena a convertir</param>
        /// <returns>Decimal si es pot convertir, '0' en cas contrari</returns>
        public static decimal ParseDecimal(string numero)
        {
            decimal result = 0;
            if (decimal.TryParse(numero, out result))
            {
                return result;
            }
            else
            {
                return 0;
            }
        }

        /// <summary>
        /// Intenta convertir una cadena de text a int
        /// </summary>
        /// <param name="numero">Cadena a convertir</param>
        /// <returns>Int32 si es pot convertir, '0' en cas contrari</returns>
        public static Int32 ParseInt32(string numero)
        {
            Int32 result = 0;
            if (Int32.TryParse(numero, out result))
            {
                return result;
            }
            else
            {
                return 0;
            }
        }

        /// <summary>
        /// Intenta convertir una cadena de text a booleà
        /// </summary>
        /// <param name="cadena">Cadena a convertir</param>
        /// <returns>Cert si la cadena és igual a 'true', 'cert', 's' o 't' 
        /// (majuscules o minúscules), o bé un número més gran que zero. 
        /// Fals en cas contrari</returns>
        public static bool ParseBool(string cadena)
        {
            if (string.IsNullOrEmpty(cadena))
            {
                return false;
            }
            string[] valors = new string[]{"TRUE","CERT","S","T"};
            if (valors.Contains(cadena.ToUpper())){
                return true;
            }
            return (ParseInt32(cadena) > 0);
        }
    }
}
