﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Data.Infrastructure.Dao;
using NHibernate;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Resources;
using Gaudeix.Common.Models.Compra;
using Gaudeix.Common.Utils;
using Gaudeix.Data.Infrastructure.Factory;
using Gaudeix.Common.Models.Users;
using Gaudeix.Common.Models.Common;

namespace Gaudeix.Data.Dao
{
    public class CompraUsuariDao : BaseDao<CompraUsuari, int>, ICompraUsuariDao
    {
        #region ICompraUsuariDao Members

        public IList<ItemLlistaCompres> ConsultarCompres(ParamsSearchCompres parametres)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetCompresUsuariByFiltre");
                query.SetString("titol", QueryUtils.FormatLikeMiddleParam(parametres.Titol));
                query.SetInt32("idProvincia", parametres.IdProvincia);
                query.SetInt32("idPoblacio", parametres.IdPoblacio);
                query.SetInt32("idEmpresa", parametres.IdEmpresa);
                query.SetDecimal("preuBaseInit", parametres.PreuBaseDesDe);
                query.SetDecimal("preuBaseFi", parametres.PreuBaseFins);
                query.SetDecimal("preuVendaInit", parametres.PreuVendaDesDe);
                query.SetDecimal("preuVendaFi", parametres.PreuVendaFins);
                DateTime date0 = new DateTime(0);
                if (parametres.DataIniciDesDe.Equals(date0))
                {
                    query.SetDateTime("dataIniciDesDe", QueryUtils.GetMinDataIniciFiltre());
                }
                else
                {
                    query.SetDateTime("dataIniciDesDe", parametres.DataIniciDesDe);
                }

                if (parametres.DataIniciFins.Equals(date0))
                {
                    query.SetDateTime("dataIniciFins", QueryUtils.GetMaxDataFiFiltre());
                }
                else
                {
                    query.SetDateTime("dataIniciFins", parametres.DataIniciFins);
                }

                if (parametres.DataFiDesDe.Equals(date0))
                {
                    query.SetDateTime("dataFiDesDe", QueryUtils.GetMinDataIniciFiltre());
                }
                else
                {
                    query.SetDateTime("dataFiDesDe", parametres.DataFiDesDe);
                }

                if (parametres.DataFiFins.Equals(date0))
                {
                    query.SetDateTime("dataFiFins", QueryUtils.GetMaxDataFiFiltre());
                }
                else
                {
                    query.SetDateTime("dataFiFins", parametres.DataFiFins);
                }
                // Categories
                if ((parametres.Categories != null) && (parametres.Categories.Count() > 0))
                {
                    query.SetParameterList("listCategories", parametres.Categories);
                }
                else
                {
                    query.SetParameterList("listCategories", new int[] { 0 });
                }
                IList<ItemLlistaCompres> resultat = query.List<ItemLlistaCompres>();

                resultat = resultat.Distinct(new ItemLlistaCompresComparer()).ToList<ItemLlistaCompres>();

                return resultat;
            }
            catch (Exception ex)
            {
                logger.Error("CompraUsuariDao.ConsultarOfertes", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public int GuardarCompra(int idOferta, int idUsuari)
        {
            try
            {
                IOfertaDao ofertaDao = DaoFactory.GetDao<IOfertaDao>();
                Oferta oferta = ofertaDao.GetById(idOferta);
                CompraUsuari compra = new CompraUsuari();
                compra.Usuari = new Usuari(idUsuari);
                compra.Oferta = oferta;
                compra.DataCompra = DateTime.Now;
                compra.PreuBase = oferta.PreuBase;
                compra.PreuCompra = oferta.PreuVenda;

                return this.Save(compra);
            }
            catch (Exception ex)
            {
                logger.Error("CompraUsuariDao.GuardarCompra", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<ItemCompresUsuari> GetCompresUsuari(int idUsuari)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetCompresUsuariByIdUsuari");
                query.SetInt32("idUsuari", idUsuari);
                return query.List<ItemCompresUsuari>();
            }
            catch (Exception ex)
            {
                logger.Error("CompraUsuariDao.GetCompresUsuari", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<ItemDataValor> GetEstadisticaVendes()
        {
            try
            {
                DateTime dataFiltre = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day).AddDays(-7);
                IQuery query = Session.GetNamedQuery("GetEstadisticaVendes");
                query.SetDateTime("dataMinima", dataFiltre);
                return query.List<ItemDataValor>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetEstadisticaRegistres", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<ItemDataValor> GetEstadisticaBeneficis()
        {
            try
            {
                DateTime dataFiltre = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day).AddDays(-7);
                IQuery query = Session.GetNamedQuery("GetEstadisticaBeneficis");
                query.SetDateTime("dataMinima", dataFiltre);
                return query.List<ItemDataValor>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetEstadisticaRegistres", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        #endregion
    }
}
