﻿using System;
using System.Collections.Generic;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Models.Empresa;
using Gaudeix.Common.Resources;
using Gaudeix.Common.Utils;
using Gaudeix.Data.Infrastructure.Dao;
using NHibernate;

namespace Gaudeix.Data.Dao
{
    public class EmpresaDao : BaseDao<Empresa, int>, IEmpresaDao
    {
        #region IEmpresaDao Members

        public IList<ItemLlistaEmpreses> ConsultarEntitats(ParamsSearchEmpreses parametres)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetEmpresesByFiltre");
                query.SetString("cif", parametres.Cif);
                query.SetString("nom", QueryUtils.FormatLikeMiddleParam(parametres.Nom));
                query.SetString("mail", parametres.Email);
                query.SetInt32("idProvincia", parametres.IdProvincia);
                query.SetInt32("idPoblacio", parametres.IdPoblacio);
                return query.List<ItemLlistaEmpreses>();
            }
            catch (Exception ex)
            {
                logger.Error("EmpresaDao.ConsultarEntitats", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public DetallEmpresa GetDetallEmpresa(int idEmpresa)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetDetallEmpresaById");
                query.SetInt32("idEmpresa", idEmpresa);
                return query.UniqueResult<DetallEmpresa>();
            }
            catch (Exception ex)
            {
                logger.Error("EmpresaDao.GetDetallEmpresa", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<ItemOfertesEmpresa> GetOfertesEmpresa(int idEmpresa)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetOfertesEmpresaByIdEmpresa");
                query.SetInt32("idEmpresa", idEmpresa);
                return query.List<ItemOfertesEmpresa>();
            }
            catch (Exception ex)
            {
                logger.Error("EmpresaDao.GetOfertesEmpresa", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }


        public IList<string> GetAllEmailsFromEmpreses()
        {
            try{
                IQuery query = Session.GetNamedQuery("GetAllEmailsFromEmpreses");
                return query.List<string>();
            }
            catch (Exception ex)
            {
                logger.Error("EmpresaDao.GetAllEmailsFromEmpreses", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        #endregion
    }
}
