﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Data.Infrastructure.Dao;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Models.Oferta;
using NHibernate;
using Gaudeix.Common.Utils;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Resources;
using Gaudeix.Common.Models.Browse;
using Gaudeix.Common.Models.Common;
using Gaudeix.Common.Constants;

namespace Gaudeix.Data.Dao
{
    public class OfertaDao : BaseDao<Oferta, int>, IOfertaDao
    {
        #region IOfertaDao Members

        public IList<ItemLlistaOfertes> ConsultarOfertesPaginat(ParamsSearchOfertes parametres,
            int numPlana, int numRegsPlana)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetOfertesByFiltre");
                
                // Consultem si s'ha d'ordenar la consulta
                string ordre = this.GetOrdreConsultaOfertes(parametres.IdOrdenacio);
                if (!String.IsNullOrEmpty(ordre))
                {
                    // En cas afirmatiu, obtenim la query SQL de la consulta, afegim l'ordre
                    // i tornem a generar l'objecte IQuery
                    string sQuery = query.QueryString;
                    sQuery = sQuery + ordre;
                    query = Session.CreateQuery(sQuery);
                }

                query.SetString("titol", QueryUtils.FormatLikeMiddleParam(parametres.Titol));
                query.SetInt32("idEmpresa", parametres.IdEmpresa);
                query.SetDecimal("preuBaseInit", parametres.PreuBaseInit);
                query.SetDecimal("preuBaseFi", parametres.PreuBaseFi);
                query.SetDecimal("preuVendaInit", parametres.PreuVendaInit);
                query.SetDecimal("preuVendaFi", parametres.PreuVendaFi);
                query.SetInt32("idProvincia", parametres.idProvincia);
                query.SetInt32("idPoblacio", parametres.idPoblacio);
                DateTime date0 = new DateTime(0);


                if (parametres.DataIniciDesDe.Equals(date0))
                {
                    query.SetDateTime("dataIniciDesDe", QueryUtils.GetMinDataIniciFiltre());
                }
                else
                {
                    query.SetDateTime("dataIniciDesDe", parametres.DataIniciDesDe);
                }

                if (parametres.DataIniciFins.Equals(date0))
                {
                    query.SetDateTime("dataIniciFins", QueryUtils.GetMaxDataFiFiltre());
                }
                else
                {
                    query.SetDateTime("dataIniciFins", parametres.DataIniciFins);
                }

                if (parametres.DataFiDesDe.Equals(date0))
                {
                    query.SetDateTime("dataFiDesDe", QueryUtils.GetMinDataIniciFiltre());
                }
                else
                {
                    query.SetDateTime("dataFiDesDe", parametres.DataFiDesDe);
                }

                if (parametres.DataFiFins.Equals(date0))
                {
                    query.SetDateTime("dataFiFins", QueryUtils.GetMaxDataFiFiltre());
                }
                else
                {
                    query.SetDateTime("dataFiFins", parametres.DataFiFins);
                }
                // Categories
                if ((parametres.idCategories != null) && (parametres.idCategories.Count() > 0))
                {
                    query.SetParameterList("listCategories", parametres.idCategories);
                }
                else
                {
                    query.SetParameterList("listCategories", new int[] { 0 });
                }

                // Obtenim la ordenacio
                if (numPlana >= 0)
                {
                    query.SetFirstResult(numPlana * numRegsPlana);
                    query.SetFetchSize(numRegsPlana + 1);
                    query.SetMaxResults(numRegsPlana + 1);
                }
                return query.List<ItemLlistaOfertes>();
            }
            catch (Exception ex)
            {
                logger.Error("OfertaDao.ConsultarOfertes", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }


        }

        private string GetOrdreConsultaOfertes(int idOrdenacio)
        {
            string ordenacio = String.Empty;
            switch (idOrdenacio)
            {
                case CommonConstants.ORDER_BY_PREU_ASC:
                    ordenacio = " ORDER BY o.PreuVenda ASC, o.Id ASC";
                    break;
                case CommonConstants.ORDER_BY_PREU_DESC:
                    ordenacio = " ORDER BY o.PreuVenda DESC, o.Id ASC";
                    break;
                case CommonConstants.ORDER_BY_TITOL_ASC:
                    ordenacio = " ORDER BY o.Titol ASC, o.Id ASC";
                    break;
                case CommonConstants.ORDER_BY_TITOL_DESC:
                    ordenacio = " ORDER BY o.Titol DESC, o.Id ASC";
                    break;
                case CommonConstants.ORDER_BY_DATA_ASC:
                    ordenacio = " ORDER BY o.DataFi ASC, o.Id ASC";
                    break;
                case CommonConstants.ORDER_BY_DATA_DESC:
                    ordenacio = " ORDER BY o.DataFi DESC, o.Id ASC";
                    break;
            }
            return ordenacio;
        }

        public IList<ItemLlistaOfertes> ConsultarOfertes(ParamsSearchOfertes parametres)
        {
            return ConsultarOfertesPaginat(parametres, -1, -1);
        }

        public DetallOfertaWcf GetDetallOfertaForWCF(int idOferta)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetDetallOfertaById");
                query.SetInt32("idOferta", idOferta);
                return query.UniqueResult<DetallOfertaWcf>();
            }
            catch (Exception ex)
            {
                logger.Error("OfertaDao.GetDetallOferta", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }


        }

        public DetallOfertaModel GetDetallOfertaForWeb(int idOferta)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetDetallOfertaForWebById");
                query.SetInt32("idOferta", idOferta);
                return query.UniqueResult<DetallOfertaModel>();
            }
            catch (Exception ex)
            {
                logger.Error("OfertaDao.GetDetallOfertaForWeb", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public int ActualitzarEstadistiques(int idOferta)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("UpdateEstadistiquesOferta");
                query.SetInt32("idOferta", idOferta);
                return query.ExecuteUpdate();
            }
            catch (Exception ex)
            {
                logger.Error("OfertaDao.GetDetallOfertaForWeb", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public void AfegirVisita(int idOferta)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("AfegirVisitaOferta");
                query.SetInt32("idOferta", idOferta);
                query.ExecuteUpdate();
            }
            catch (Exception ex)
            {
                logger.Error("OfertaDao.GetDetallOfertaForWeb", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public void AfegirCompra(int idOferta)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("AfegirCompraOferta");
                query.SetInt32("idOferta", idOferta);
                query.ExecuteUpdate();
            }
            catch (Exception ex)
            {
                logger.Error("OfertaDao.GetDetallOfertaForWeb", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<ItemDataValor> GetEstadisticaPublicacions()
        {
            try
            {
                DateTime dataFiltre = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day).AddDays(-7);
                IQuery query = Session.GetNamedQuery("GetEstadisticaPublicacions");
                query.SetDateTime("dataMinima", dataFiltre);
                return query.List<ItemDataValor>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetEstadisticaRegistres", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<Oferta> GetTopOfertes(int idCategoria)
        {
            try{
                DateTime dataFiltre = new DateTime(
                    DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day).AddDays(-7);
                IQuery query = Session.GetNamedQuery("GetTopOfertesByCategoria");
                query.SetDateTime("dataMinima", dataFiltre);
                query.SetInt32("idCategoria", idCategoria);
                query.SetMaxResults(3);
                return query.List<Oferta>();
             }
            catch (Exception ex)
            {
                logger.ErrorFormat(ex, "UsuariDao.GetEstadisticaRegistres({0}}", idCategoria);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        #endregion
    }
}
