﻿using System;
using System.Linq;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Resources;
using Gaudeix.Data.Infrastructure.Dao;
using NHibernate;
using Gaudeix.Common.Models.Users;
using System.Collections.Generic;
using Gaudeix.Common.Models.Common;

namespace Gaudeix.Data.Dao
{
    public class UsuariDao : BaseDao<Usuari, int>, IUsuariDao
    {
        #region IUsuariDao Members

        public Usuari GetByUsername(string username)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetUserById");
                query.SetString("pUsername", username);
                // Degut a que el username és una UK a la BD, podem fer un UniqueResult()
                return query.UniqueResult<Usuari>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetByUsername", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public Usuari GetByNif(string nif)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetUserByNif");
                query.SetString("nif", nif);
                // Degut a que el nif és una UK a la BD, podem fer un UniqueResult()
                return query.UniqueResult<Usuari>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetByNif", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<ItemLlistaUsuaris> ConsultarOfertes(ParamsSearchUsuaris parametres)
        {
            try
            {
                bool filtreInteressos;
                IQuery query;
                if ((parametres.Interessos != null) && (parametres.Interessos.Count() > 0))
                {
                    filtreInteressos = true;
                    query = Session.GetNamedQuery("GetUsuarisByFiltreWithInteressos");
                }
                else
                {
                    filtreInteressos = false;
                    query = Session.GetNamedQuery("GetUsuarisByFiltre");
                }
                query.SetString("nom", parametres.Nom);
                query.SetString("cognom1", parametres.Cognom1);
                query.SetString("cognom2", parametres.Cognom2);
                query.SetString("nif", parametres.Nif);
                query.SetString("email", parametres.Email);
                query.SetInt32("idProvincia", parametres.IdProvincia);
                query.SetInt32("idPoblacio", parametres.IdPoblacio);
                // Categories
                if (filtreInteressos)
                {
                    query.SetParameterList("listCategories", parametres.Interessos);
                }
                return query.List<ItemLlistaUsuaris>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetDetallUsuari", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public DetallUsuari GetDetallUsuari(int idUsuari)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetDetallUsuariById");
                query.SetInt32("idUsuari", idUsuari);
                return query.UniqueResult<DetallUsuari>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetDetallUsuari", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<string> GetAllEmailsFromUsers()
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetAllMailsFromUsuaris");
                return query.List<string>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetAllMailsFromUsers", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<ItemDataValor> GetEstadisticaRegistres()
        {
            try
            {
                DateTime dataFiltre = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day).AddDays(-7);
                IQuery query = Session.GetNamedQuery("GetEstadisticaRegistres");
                query.SetDateTime("dataMinima", dataFiltre);
                return query.List<ItemDataValor>();
            }
            catch (Exception ex)
            {
                logger.Error("UsuariDao.GetEstadisticaRegistres", ex);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        public IList<Usuari> GetMailUsersByIdCategoria(int idCategoria)
        {
            try
            {
                IQuery query = Session.GetNamedQuery("GetMailUsersByIdCategoria");
                query.SetInt32("idCategoria", idCategoria);
                return query.List<Usuari>();
            }
            catch (Exception ex)
            {
                logger.ErrorFormat(ex, "UsuariDao.GetEstadisticaRegistres({0})", idCategoria);
                throw new GaudeixDaoException(CommonErrors.ErrorBD, ex);
            }
        }

        #endregion
    }
}
