﻿using System;
using Castle.Windsor;
using Gaudeix.Data.Infrastructure.Installers;
using Gaudeix.Common.Infrastructure.Installer;

namespace Gaudeix.Data.Infrastructure.Factory
{
    /// <summary>
    /// Classe estàtica encarregada de servir de factoria d'instàncies de les classes DAO
    /// </summary>
    public sealed class DaoFactory
    {
        /// <summary>
        /// Variable estàtica per al contenidor, que només s'inicialitzarà un cop.
        /// </summary>
        private static readonly Lazy<IWindsorContainer> container = new Lazy<IWindsorContainer>(() =>
         {

             IWindsorContainer cont = new WindsorContainer();
             cont.Install(new DaoInstaller());
             cont.Install(new LoggerInstaller());
             return cont;
         }, System.Threading.LazyThreadSafetyMode.ExecutionAndPublication);

        /// <summary>
        /// Retorna una instància d'un objecte DAO, a través de la seva interficie
        /// </summary>
        /// <typeparam name="T">Interficie a través de la que accedim a l'objecte DAO</typeparam>
        /// <returns>Instancia accessible a través de la interficie</returns>
        public static T GetDao<T>()
        {
            return container.Value.Resolve<T>();
        }

    }

}

