﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Castle.Windsor;
using Gaudeix.Manager.Infrastructure;
using Gaudeix.Common.Infrastructure.Installer;
using Gaudeix.Manager.Infrastructure.Installers;

namespace Gaudeix.Manager.Infrastructure.Factory
{
    // Classe estàtica encarregada de servir de factoria d'instàncies del manager
    public static class ManagerFactory
    {
        // Variable estàtica per a la instància, que només s'inicialitzarà un cop.
        private static readonly Lazy<IWindsorContainer> container = new Lazy<IWindsorContainer>(() =>
        {
            IWindsorContainer cont = new WindsorContainer();
            cont.Install(new ManagerInstaller());
            cont.Install(new LoggerInstaller());
            return cont;
        }, System.Threading.LazyThreadSafetyMode.ExecutionAndPublication);

        /// <summary>
        /// Retorna una instància d'un objecte Manager, a través de la seva interficie
        /// </summary>
        /// <typeparam name="T">Interficie a través de la que accedim al manager</typeparam>
        /// <returns>Instancia accessible a través de la interficie</returns>
        public static T GetManager<T>()
        {
            return container.Value.Resolve<T>();
        }

    }
}
