﻿using Castle.Core.Logging;
using Gaudeix.Common.Infrastructure.Manager;
using Gaudeix.Manager.Infrastructure.Factory;
using Gaudeix.Data.Infrastructure.Factory;

namespace Gaudeix.Manager.Infrastructure.Base
{
    /// <summary>
    /// Superclasse abstracta de la que deriven tots els managers
    /// </summary>
    public abstract class BaseManager : IBaseManager
    {
        public ILogger logger { get; set; }

        #region Mètodes protegits per als serveis
        /// <summary>
        /// Obté una instància inicialitzada d'un DAO a través de la seva interficie
        /// </summary>
        /// <typeparam name="T">Interficie del dao</typeparam>
        /// <returns>Instancia inicialitzada del dao</returns>
        protected T GetDao<T>()
        {
            return DaoFactory.GetDao<T>();
        }

        /// <summary>
        /// Obté una instància inicialitzada d'un Manager a través de la seva interficie
        /// </summary>
        /// <typeparam name="T">Interficie del Manager</typeparam>
        /// <returns>Instancia inicialitzada del Manager</returns>
        protected T GetManager<T>()
        {
            return ManagerFactory.GetManager<T>();
        }
        #endregion
        
    }
}
