﻿using System;
using System.Collections.Generic;
using System.Text;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Common.Models.Browse;
using Gaudeix.Common.Resources;
using Gaudeix.Manager.Infrastructure.Base;
using Gaudeix.Manager.Infrastructure.Factory;

namespace Gaudeix.Business.Manager
{
    public class ComentariOfertaManager : BaseManager, IComentariOfertaManager
    {
        #region IComentariOfertaManager Members

        public IList<ItemLlistaComentaris> GetComentarisOferta(int idOferta)
        {
            try
            {
                IComentariOfertaDao dao = this.GetDao<IComentariOfertaDao>();
                return dao.GetComentarisOferta(idOferta);
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("ComentariOfertaManager.GetComentarisOferta", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        public int AfegirComentari(int idOferta, string username, string comentari, short valoracio)
        {
            try
            {
                // Validacions integritat
                StringBuilder errors = new StringBuilder();
                if (idOferta <= 0)
                {
                    errors.AppendLine(CommonErrors.ErrorNoArticle);
                }
                if (String.IsNullOrEmpty(username))
                {
                    errors.AppendLine(CommonErrors.ErrorNoUsuari);
                }
                if (String.IsNullOrEmpty(comentari))
                {
                    errors.AppendLine(String.Format(CommonErrors.CampObligatori, CommonFields.Comentari));
                }
                if ((valoracio < 0) || (valoracio > 10))
                {
                    errors.AppendLine(CommonErrors.ErrorRangValidacio);
                }
                if (errors.Length > 0)
                {
                    throw new GaudeixBusinessException(errors.ToString());
                }

                // Recuperar id usuari
                IUsuariManager userManager = this.GetManager<IUsuariManager>();
                int idUsuari = userManager.GetDetallUsuariByUserName(username).IdUsuari;

                // Guardar comentari
                ComentariOferta comment = new ComentariOferta();
                comment.Comentari = comentari;
                comment.DataInsercio = DateTime.Now;
                comment.Oferta = new Oferta(idOferta);
                comment.Usuari = new Usuari(idUsuari);
                comment.UsuariCertificat = userManager.OfertaCompradaPerUsuari(idOferta, idUsuari);
                comment.Valoracio = valoracio;

                IComentariOfertaDao dao = this.GetDao<IComentariOfertaDao>();
                int result = dao.Save(comment);

                // Actualitzar estadistiques
                IOfertaManager ofertaManager = this.GetManager<IOfertaManager>();
                ofertaManager.ActualitzarEstadistiques(idOferta);
                return result;
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("ComentariOfertaManager.GetComentarisOferta", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        #endregion
    }
}
