﻿using System;
using System.Collections.Generic;
using System.Text;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Common.Models.Compra;
using Gaudeix.Common.Models.Users;
using Gaudeix.Common.Resources;
using Gaudeix.Common.Utils;
using Gaudeix.Data.Infrastructure.Factory;
using Gaudeix.Manager.Infrastructure.Base;
using Gaudeix.Manager.Infrastructure.Factory;
using Gaudeix.Common.Domain.Entities;

namespace Gaudeix.Business.Manager
{
    public class CompraUsuariManager : BaseManager, ICompraUsuariManager
    {

        #region ICompraUsuariManager Members

        public IList<ItemLlistaCompres> ConsultarCompres(ParamsSearchCompres parametres)
        {
            if (parametres.NumParametresInformats <= 0)
            {
                throw new GaudeixBusinessException(CommonErrors.NoParametresCerca);
            }
            try
            {
                return this.GetDao<ICompraUsuariDao>().ConsultarCompres(parametres);
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("CompraUsuariManager.ConsultarCompres", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        public int ComprarArticle(int idArticle, string username, string numTarjaCredit, string codiValidacio, string linkOferta)
        {
            try
            {

                StringBuilder errors = new StringBuilder();
                if (idArticle <= 0)
                {
                    errors.AppendLine(CommonErrors.ErrorNoArticle);
                }
                if (String.IsNullOrEmpty(username))
                {
                    errors.AppendLine(CommonErrors.ErrorNoUsuari);
                }
                // Validar tarja de credit
                if (!ValidationUtils.IsTarjaValida(numTarjaCredit, codiValidacio))
                {
                    errors.AppendLine(CommonErrors.ErrorTarjaNoValida);
                }
                if (errors.Length > 0)
                {
                    throw new GaudeixBusinessException(errors.ToString());
                }
                // Guardar compra a BBDD
                DetallUsuari user = this.GetManager<IUsuariManager>().GetDetallUsuariByUserName(username);
                int idCompra = this.GetDao<ICompraUsuariDao>().GuardarCompra(idArticle, user.IdUsuari);

                // Actualitzem el número de compres
                IOfertaDao ofertaDao = this.GetDao<IOfertaDao>();
                ofertaDao.AfegirCompra(idArticle);

                // Enviar correu de confirmació de compra per a l'usuari
                ICuaCorreuManager correuManager = this.GetManager<ICuaCorreuManager>();
                correuManager.EnqueueMailCompraUsuari(idCompra, linkOferta);

                // Enviar correu de confirmació de compra per a la empresa
                correuManager.EnqueueMailCompraEmpresa(idCompra, linkOferta);
                return idCompra;
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("CompraUsuariManager.ConsultarCompres", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        #endregion
    }
}
