﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Manager.Infrastructure.Base;
using Gaudeix.Common.Models.Common;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Dao;

namespace Gaudeix.Business.Manager
{
    public class EstadistiquesManager:BaseManager, IEstadistiquesManager 
    {
        #region IEstadistiquesManager Members

        public IList<ItemDataValor> GetEstadisticaVendes()
        {
            try{
                IList<ItemDataValor> resultat = this.GetDao<ICompraUsuariDao>().GetEstadisticaVendes();
                
                DateTime data = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day);
                data = data.AddDays(-7);
                DateTime dataAux;
                for (int i = 0; i < 7; i++)
                {
                    dataAux = data.AddDays(i);
                    if (resultat.Where(v => v.Data == dataAux).Count() == 0)
                    {
                        resultat.Insert(i, new ItemDataValor(dataAux, 0));
                    }
                }
                return resultat;
             }
            catch (GaudeixDaoException ex)
            {
                logger.Error("EstadistiquesManager.GetEstadisticaVendes", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        public IList<ItemDataValor> GetEstadisticaBeneficis()
        {
            try
            {
                IList<ItemDataValor> resultat = this.GetDao<ICompraUsuariDao>().GetEstadisticaBeneficis();
                DateTime data = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day);
                data = data.AddDays(-7);
                DateTime dataAux;
                for (int i = 0; i < 7; i++)
                {
                    dataAux = data.AddDays(i);
                    if (resultat.Where(v => v.Data == dataAux).Count() == 0)
                    {
                        resultat.Insert(i, new ItemDataValor(dataAux, 0));
                    }
                }
                return resultat;
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("EstadistiquesManager.GetEstadisticaBeneficis", ex);
                throw new GaudeixBusinessException(ex);
            }
            
        }

        public IList<ItemDataValor> GetEstadisticaRegistres()
        {
            try
            {
                IList<ItemDataValor> resultat = this.GetDao<IUsuariDao>().GetEstadisticaRegistres();
                DateTime data = new DateTime (DateTime.Now.Year,DateTime.Now.Month,DateTime.Now.Day);
                data = data.AddDays(-7);
                DateTime dataAux;
                for (int i = 0; i <7; i++)
                {
                    dataAux = data.AddDays(i);
                    if (resultat.Where(v => v.Data == dataAux).Count() == 0)
                    {
                        resultat.Insert(i, new ItemDataValor(dataAux, 0));
                    }
                }
                return resultat;
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("EstadistiquesManager.GetEstadisticaRegistres", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        public IList<ItemDataValor> GetEstadisticaPublicacions()
        {
            try
            {
                IList<ItemDataValor> resultat = this.GetDao<IOfertaDao>().GetEstadisticaPublicacions();
                DateTime data = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day);
                data = data.AddDays(-7);
                DateTime dataAux;
                for (int i = 0; i < 7; i++)
                {
                    dataAux = data.AddDays(i);
                    if (resultat.Where(v => v.Data == dataAux).Count() == 0)
                    {
                        resultat.Insert(i, new ItemDataValor(dataAux, 0));
                    }
                }
                return resultat;
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("EstadistiquesManager.GetEstadisticaPublicacions", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        #endregion

   
    }
}
