﻿using System.Collections.Generic;
using Gaudeix.Common.Domain.Entities;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Common.Models.Admin;
using Gaudeix.Manager.Infrastructure.Base;

namespace Gaudeix.Business.Manager
{
    public class ParametreManager : BaseManager, IParametreManager
    {
        #region IParametreManager Members

        public string GetParamValueByCodi(string codiParametre)
        {
            try
            {
                IParametreDao dao = this.GetDao<IParametreDao>();
                return dao.GetParamValueByCodi(codiParametre);
            }
            catch (GaudeixDaoException ex)
            {
                // Control d'excepcions del DAO
                logger.Error("ParametreManager.GetParamValueByCodi", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        public IList<ParametreModel> GetAllParametres()
        {
            try
            {
                IParametreDao dao = this.GetDao<IParametreDao>();
                return dao.GetAllParametres();
            }
            catch (GaudeixDaoException ex)
            {
                // Control d'excepcions del DAO
                logger.Error("ParametreManager.GetAllParametres", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        public void UpdateParamValue(int idParametre, string nouValor)
        {
            try
            {
                IParametreDao dao = this.GetDao<IParametreDao>();
                Parametre param = dao.GetById(idParametre);
                param.Valor = nouValor;
                dao.SaveOrUpdate(param);
            }
            catch (GaudeixDaoException ex)
            {
                // Control d'excepcions del DAO
                logger.Error("ParametreManager.UpdateParamValue", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        #endregion
    }
}
