﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Manager.Infrastructure.Base;
using Gaudeix.Common.Models.Common;
using Gaudeix.Common.Interfaces.Dao;
using Gaudeix.Common.Exceptions;

namespace Gaudeix.Business.Manager
{
    public class TaulesBaseManager : BaseManager, ITaulesBaseManager
    {
        #region ITaulesBaseManager Members

        public IList<ItemIdDescripcio> GetCategories()
        {
            try
            {
                return this.GetDao<ICategoriaDao>().GetCategories();
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("TaulesBaseManager.GetCategories", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        public IList<ItemIdDescripcio> GetPoblacionsByIdProvincia(int idProvincia)
        {
            try
            {
                IPoblacioDao dao = this.GetDao<IPoblacioDao>();
                if (idProvincia <= 0)
                {
                    // No ens han passat cap provincia
                    logger.Debug("No s'ha passat un codi vàlid de província");
                    return new List<ItemIdDescripcio>();
                }
                else
                {
                    return dao.GetPoblacionsByIdProvincia(idProvincia);
                }
            }
            catch (GaudeixDaoException ex)
            {
                logger.ErrorFormat(ex, "PoblacioManager.GetPoblacionsByIdProvincia({0})", idProvincia);
                throw new GaudeixBusinessException(ex);
            }
        }

        public IList<ItemIdDescripcio> GetProvincies()
        {
            try
            {
                IProvinciaDao dao = this.GetDao<IProvinciaDao>();
                return dao.GetProvincies();
            }
            catch (GaudeixDaoException ex)
            {
                logger.Error("ProvinciaManager.GetProvincies", ex);
                throw new GaudeixBusinessException(ex);
            }
        }

        #endregion
    }
}
