﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.Text;

namespace Gaudeix.WCF.Contracts
{
    /// <summary>
    /// Contracte per operacions sobre enviament de correus electrònics
    /// </summary>
    [ServiceContract]
    public interface IEMail
    {
        
        /// <summary>
        /// Encua un correu electrònic per a que sigui processat pel procés d'enviament de correu
        /// </summary>
        /// <param name="destinatari">email del destinatari</param>
        /// <param name="titol">Titol del correu</param>
        /// <param name="message">Missatge del correu</param>
        [OperationContract]
        void EnqueueMail(string destinatari, string titol, string message);

        /// <summary>
        /// Encua un correu electrònic per a múltiples usuaris per a que sigui processat pel 
        /// procés d'enviament de correu
        /// </summary>
        /// <param name="destinataris">emails dels destinataris</param>
        /// <param name="titol">Titol del correu</param>
        /// <param name="message">Missatge del correu</param>
        [OperationContract]
        void EnqueueMultirecipientMail(string[] destinataris, string titol, string message);

        /// <summary>
        /// Encua una petició d'enviament massiu de correus
        /// </summary>
        /// <param name="allUsuaris">Indica si el correu s'ha d'enviar a tots els usuaris</param>
        /// <param name="allEmpreses">Indica si el correu s'ha d'enviar a totes les empreses</param>
        /// <param name="titol">Titol del correu</param>
        /// <param name="message">Text del missatge</param>
        [OperationContract]
        void EnqueueGlobalMail(bool allUsuaris, bool allEmpreses, string titol, string message);

    }
}
