﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ServiceModel;
using Gaudeix.Common.Models.Empresa;

namespace Gaudeix.WCF.Contracts
{
    /// <summary>
    /// Contracte per operacions sobre les Entitats (Empreses) adherides al portal
    /// </summary>
    [ServiceContract]
    public interface IEntitats
    {
        #region Mètodes a implementar
        /// <summary>
        /// Guarda l'entitat a la base de dades. 
        /// Si no existeix es crea un nou registre, i si existeix 
        /// s'actualitza el registre segons les dades subministrades.
        /// </summary>
        /// <param name="empresa">Dades de l'empresa</param>
        /// <returns>PK de la nova entitat guardada o actualitzada</returns>
        [OperationContract]
        int GuardarEntitat(DetallEmpresa empresa);

        /// <summary>
        /// Retorna un llistat de les entitats que compleixen els paràmetres de cerca.
        /// </summary>
        ///<param name="parametres">Paràmtres de cerca</param>
        /// <returns>Llista d'entitats que compleixen amb els paràmetres de cerca</returns>
        [OperationContract]
        IList<ItemLlistaEmpreses> ConsultarEntitats(ParamsSearchEmpreses parametres);

        /// <summary>
        /// Obté el detall d'una empresa a partir de la seva clau primaria
        /// </summary>
        /// <param name="idEmpresa">Clau primèria de l'empresa</param>
        /// <returns>Detall de l'empresa</returns>
        [OperationContract]
        DetallEmpresa GetDetallEmpresa(int idEmpresa);

        /// <summary>
        /// Esborra les empreses indicades de la BD
        /// </summary>
        /// <param name="idEmpreses">ID's d'empreses a esborrar</param>
        [OperationContract]
        void EsborrarEmpreses(int[] idEmpreses);
        #endregion
    }
}
