﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.Text;
using Gaudeix.Common.Models.Browse;
using Gaudeix.Common.Models.Oferta;

namespace Gaudeix.WCF.Contracts
{
    /// <summary>
    /// Contracte per operacions sobre les ofertes publicades al portal
    /// </summary>
    [ServiceContract]
    public interface IOfertes
    {
        /// <summary>
        /// Guarda la oferta a la base de dades. 
        /// Si no existeix es crea un nou registre, i si existeix 
        /// s'actualitza el registre segons les dades subministrades.
        /// </summary>
        /// <param name="oferta">Dades de la oferta</param>
        /// <param name="imatge">Imatge de la oferta (si es passa el valor null no es modificarà la imatge)</param>
        /// <returns>PK de la nova oferta guardada o actualitzada</returns>
        [OperationContract]
        int GuardarOfertaFromWCF(DetallOfertaWcf oferta);

        /// <summary>
        /// Retorna un llistat de les ofertes que compleixen els paràmetres de cerca.
        /// </summary>
        /// <returns>Llista d'ofertes que compleixen amb els paràmetres de cerca</returns>
        [OperationContract]
        IList<ItemLlistaOfertes> ConsultarOfertes(ParamsSearchOfertes parametres);

        /// <summary>
        /// Obté el detall d'una oferta a partir de la seva clau primaria
        /// </summary>
        /// <param name="idEmpresa">Clau primària de la oferta</param>
        /// <param name="carregarImatge">Indica si es vol recuperar la imatge de la BD</param>
        /// <returns>Detall de la oferta</returns>
        [OperationContract]
        DetallOfertaWcf GetDetallOfertaForWCF(int idOferta, bool carregarImatge);

        /// <summary>
        /// Permet esborrar una o més ofertes del sistema
        /// </summary>
        /// <param name="idOfertes">Codis d'oferta a esborrar</param>
        [OperationContract]
        void EsborrarOfertes(int[] idOfertes);

    }
}
