﻿using System.Collections.Generic;
using System.ServiceModel;
using Gaudeix.Common.Models.Common;
using Gaudeix.Common.Models.Admin;

namespace Gaudeix.WCF.Contracts
{

    /// <summary>
    /// Contracte per operacions sobre les taules base
    /// </summary>
    [ServiceContract]
    public interface ITaulesBase
    {
        #region Mètodes a implementar
        /// <summary>
        /// Obté la llista de les provincies donades d'alta al sistema
        /// </summary>
        /// <returns>LLista de provincies</returns>
        [OperationContract]
        IList<ItemIdDescripcio> GetLlistaProvincies();

        /// <summary>
        /// Obté la llista de poblacions d'una provincia
        /// </summary>
        /// <param name="idProvincia">Codi de provincia a cercar</param>
        /// <returns>Llista de poblacions de la provincia</returns>
        [OperationContract]
        IList<ItemIdDescripcio> GetLlistaPoblacionsByProvincia(int idProvincia);

        /// <summary>
        /// Obté la llista de categories donades d'alta al sistema
        /// </summary>
        /// <returns>Llista de categories</returns>
        [OperationContract]
        IList<ItemIdDescripcio> GetLlistaCategories();

        /// <summary>
        /// Obté un llistat de tots els paràmetres donats d'alta al sistema
        /// </summary>
        /// <returns>Llistat de paràmetres</returns>
        [OperationContract]
        IList<ParametreModel> GetAllParametres();

        /// <summary>
        /// Actualitza el valor d'un paràmetre
        /// </summary>
        /// <param name="idParametre">Clau del paràmetre a actualitzar</param>
        /// <param name="nouValor">Nou valor del paràmetre</param>
        [OperationContract]
        void UpdateParamValue(int idParametre, string nouValor);
        #endregion
    }
}
