﻿using System.Collections.Generic;
using Gaudeix.Common.Models.Users;
using System.ServiceModel;

namespace Gaudeix.WCF.Contracts
{
    /// <summary>
    /// Contracte per operacions sobre els usuaris donats d'alta al portal
    /// </summary>
    [ServiceContract]
    public interface IUsuaris
    {
        /// <summary>
        /// Guarda les dades d'un usuari a la BD
        /// </summary>
        /// <param name="usuari">Dades a guardar</param>
        /// <param name="updatePassword">Indica si s'ha de canviar el password</param>
        /// <returns>ID del registre creat / modificat</returns>
        [OperationContract]
        int GuardarUsuari(DetallUsuari usuari, bool updatePassword);

        /// <summary>
        /// Consulta els usuaris en base a uns paràmetres de cerca
        /// </summary>
        /// <param name="paremetres">Paràmetres de cerca</param>
        /// <returns>Llista d'usuaris que compleixen els paràmetres de cerca</returns>
        [OperationContract]
        IList<ItemLlistaUsuaris> ConsultarUsuaris(ParamsSearchUsuaris paremetres);

        /// <summary>
        /// Obté el detall d'un usuari
        /// </summary>
        /// <param name="idUsuari">Codi d'usuari</param>
        /// <returns>Detall de l'usuari</returns>
        [OperationContract]
        DetallUsuari GetDetallUsuari(int idUsuari);

        /// <summary>
        /// Esborra a un usuari de la BD
        /// </summary>
        /// <param name="idUsuaris">Codi d'usuari a esborrar</param>
        [OperationContract]
        void EsborrarUsuaris(int[] idUsuaris);
    }
}