﻿using System.ServiceModel;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Manager.Infrastructure.Factory;
using Gaudeix.WCF.Contracts;
using Gaudeix.WCF.Infrastructure.Service;
using System.Collections.Generic;
using System.Linq;

namespace Gaudeix.WCF.Services
{
    /// <summary>
    /// Implementació del servei EMail
    /// </summary>
    public class EMail : BaseService, IEMail
    {

        #region IEMail Members

        public void EnqueueMail(string destinatari, string titol, string message)
        {
            try
            {
                ICuaCorreuManager manager = this.GetManager<ICuaCorreuManager>();
                manager.EnqueueMail(destinatari, titol, message);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                   new FaultReason(e.Message),
                   new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }

        public void EnqueueMultirecipientMail(string[] destinataris, string titol, string message)
        {
            try
            {
                ICuaCorreuManager manager = this.GetManager<ICuaCorreuManager>();
                foreach (string destinatari in destinataris)
                {
                    manager.EnqueueMail(destinatari, titol, message);
                }
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                   new FaultReason(e.Message),
                   new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }

        public void EnqueueGlobalMail(bool allUsuaris, bool allEmpreses, string titol, string message)
        {
            try
            {
                IList<string> emails;
                // Enviem correus a clients
                if (allUsuaris)
                {
                    IUsuariManager manager = this.GetManager<IUsuariManager>();
                    emails = manager.GetAllEmailsFromUsers();
                    this.EnqueueMultirecipientMail(emails.ToArray(), titol, message);
                }

                // Enviem correus a empreses
                if (allEmpreses)
                {
                    IEmpresaManager manager = this.GetManager<IEmpresaManager>();
                    emails = manager.GetAllEmailsFromEmpreses();
                    this.EnqueueMultirecipientMail(emails.ToArray(), titol, message);
                }
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                   new FaultReason(e.Message),
                   new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }
        #endregion
    }
}
