﻿using System.Collections.Generic;
using System.ServiceModel;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Common.Models.Empresa;
using Gaudeix.WCF.Contracts;
using Gaudeix.WCF.Infrastructure.Service;

namespace Gaudeix.WCF.Services
{
    /// <summary>
    /// Implementació del servei Entitats
    /// </summary>
    public class Entitats : BaseService, IEntitats
    {

        #region IEntitats Members

        public int GuardarEntitat(DetallEmpresa empresa)
        {
            int resultat = -1;
            try
            {
                IEmpresaManager entitat = this.GetManager<IEmpresaManager>();
                resultat = entitat.GuardarEmpresa(empresa);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                   new FaultReason(e.Message),
                   new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
            return resultat;
        }

        public IList<ItemLlistaEmpreses> ConsultarEntitats(ParamsSearchEmpreses parametres)
        {
            try
            {
                return this.GetManager<IEmpresaManager>().ConsultarEntitats(parametres);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }

        public DetallEmpresa GetDetallEmpresa(int idEmpresa)
        {
            try
            {
                return this.GetManager<IEmpresaManager>().GetDetallEmpresa(idEmpresa);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }

        }

        public void EsborrarEmpreses(int[] idEmpreses)
        {
            try
            {
                IEmpresaManager manager = GetManager<IEmpresaManager>();
                manager.EsborrarEmpreses(idEmpreses);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }
        #endregion
    }
}