﻿using System.Collections.Generic;
using System.ServiceModel;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Common.Models.Common;
using Gaudeix.Common.Resources;
using Gaudeix.WCF.Contracts;
using Gaudeix.WCF.Infrastructure.Service;
using Gaudeix.Common.Models.Admin;

namespace Gaudeix.WCF.Services
{
    /// <summary>
    /// Implementació del servei TaulesBase
    /// </summary>
    public class TaulesBase : BaseService, ITaulesBase
    {

        #region ITaulesBase Members

        public IList<ItemIdDescripcio> GetLlistaProvincies()
        {
            IList<ItemIdDescripcio> result = new List<ItemIdDescripcio>();

            try
            {
                ITaulesBaseManager manager = this.GetManager<ITaulesBaseManager>();
                result = manager.GetProvincies();
                // Afegim un primer registre per defecte:
                result.Insert(0, new ItemIdDescripcio(0, CommonFields.ComboSeleccioni));
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                new FaultReason(e.Message),
                new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
            return result;
        }

        public IList<ItemIdDescripcio> GetLlistaPoblacionsByProvincia(int idProvincia)
        {
            IList<ItemIdDescripcio> result = new List<ItemIdDescripcio>();
            try
            {
                ITaulesBaseManager manager = this.GetManager<ITaulesBaseManager>();
                result = manager.GetPoblacionsByIdProvincia(idProvincia);
                // Afegim un primer registre per defecte:
                result.Insert(0, new ItemIdDescripcio(0, CommonFields.ComboSeleccioni));
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                 new FaultReason(e.Message),
                 new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
            return result;
        }

        public IList<ItemIdDescripcio> GetLlistaCategories()
        {
            IList<ItemIdDescripcio> result = new List<ItemIdDescripcio>();
            try
            {
                ITaulesBaseManager manager = this.GetManager<ITaulesBaseManager>();
                result = manager.GetCategories();
                result.Insert(0, new ItemIdDescripcio(0, CommonFields.ComboSeleccioni));
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
            return result;
        }

        public IList<ParametreModel> GetAllParametres()
        {
            try
            {
                IParametreManager manager = this.GetManager<IParametreManager>();
                return manager.GetAllParametres();
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }

        public void UpdateParamValue(int idParametre, string nouValor)
        {
            try
            {
                this.GetManager<IParametreManager>().UpdateParamValue(idParametre, nouValor);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }

        #endregion
    }
}
