﻿using System;
using System.Collections.Generic;
using System.ServiceModel;
using Gaudeix.Common.Exceptions;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Common.Models.Users;
using Gaudeix.WCF.Contracts;
using Gaudeix.WCF.Infrastructure.Service;

namespace Gaudeix.WCF.Services
{
    /// <summary>
    /// Implementació del servei Usuaris
    /// </summary>
    public class Usuaris : BaseService, IUsuaris
    {

        #region IEntitats Members

        public int GuardarUsuari(DetallUsuari usuari, bool updatePassword)
        {
            int resultat = -1;
            try
            {
                IUsuariManager manager = this.GetManager<IUsuariManager>();
                resultat = manager.GuardarUsuari(usuari, updatePassword);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                   new FaultReason(e.Message),
                   new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
            return resultat;
        }

        public IList<ItemLlistaUsuaris> ConsultarUsuaris(ParamsSearchUsuaris parametres)
        {
            try
            {
                return this.GetManager<IUsuariManager>().ConsultarUsuaris(parametres);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }

        public DetallUsuari GetDetallUsuari(int idUsuari)
        {
            try
            {
                return this.GetManager<IUsuariManager>().GetDetallUsuariById(idUsuari);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }

        #endregion
        }

        public void EsborrarUsuaris(int[] idUsuaris)
        {
            try
            {
                IUsuariManager manager = this.GetManager<IUsuariManager>();
                manager.EsborrarUsuaris(idUsuaris);
            }
            catch (GaudeixBusinessException e)
            {
                throw new FaultException(
                    new FaultReason(e.Message),
                    new FaultCode(BaseService.FAULT_CODE_SERVER));
            }
        }


    }
}