﻿using System;
using System.Web.Mvc;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Common.Models.Users;
using Gaudeix.Manager.Infrastructure.Factory;
using Gaudeix.Web.Infrastructure.Controllers;

namespace Gaudeix.Web.Controllers
{
    /// <summary>
    /// Controlador encarregat de resoldre les peticions efectuades a través d'Ajax.
    /// </summary>
    public class AjaxController : BaseController
    {
        /// <summary>
        /// Obté la llista de poblacions a partir del ID d'una provincia
        /// </summary>
        /// <param name="id">ID de la provincia a base de dades</param>
        /// <returns>Llista de poblacions de la provincia, ordenades ascendentment per nom</returns>
        public JsonResult PoblacionsByIdProvincia(int id)
        {
            Logger.Info("INICI - GET: /Ajax/PoblacionsByIdProvincia/" + id.ToString());
            // Preparem el resultat
            JsonResult result = new JsonResult();
            try
            {
                result.JsonRequestBehavior = JsonRequestBehavior.AllowGet;
                // Instanciem el manager que recuperarà la llista de poblacions
                ITaulesBaseManager manager = this.GetManager<ITaulesBaseManager>();
                // Recuperem la llista de poblacions, i la fiquem al resultat
                result.Data = manager.GetPoblacionsByIdProvincia(id);
            }
            catch (Exception ex)
            {
                Logger.ErrorFormat(ex, "AjaxController.PoblacionsByIdProvincia({0})", id);
            }
            Logger.Info("FI - GET: /Ajax/PoblacionsByIdProvincia/" + id.ToString());
            return result;
        }

        /// <summary>
        /// Valida si existeix un usuari a partir del seu username
        /// </summary>
        /// <param name="id">Username a validar</param>
        /// <returns>JSON amb la propietat 'returnValue' que indica si existeix o no (booleà)</returns>
        public JsonResult ExistsUser(string id)
        {
            Logger.Info("INICI - GET: /Ajax/ExistsUser/" + id);
            if (null == id)
            {
                id = String.Empty;
            }
            bool valid = false;
            try
            {
                IUsuariManager manager = this.GetManager<IUsuariManager>();
                DetallUsuari detall = manager.GetDetallUsuariByUserName(id);
                valid = !((detall == null) || (detall.IdUsuari <= 0));
            }
            catch (Exception ex)
            {
                Logger.ErrorFormat(ex, "AjaxController.ExistsUser({0})", id);
                valid = false;
            }
            JsonResult result = new JsonResult();
            result.Data = new { returnValue = valid };
            Logger.Info("FI - GET: /Ajax/ExistsUser/" + id.ToString());
            return result;
        }

        /// <summary>
        /// Obté la imatge associada a una oferta
        /// </summary>
        /// <param name="id">Codi de la oferta</param>
        /// <returns>Array de bytes amb la imatge de la oferta</returns>
        public ActionResult GetImage(int id)
        {
            Logger.Info("INICI - GET: /Ajax/GetImage/" + id.ToString());
            FileContentResult resultat;
            try
            {
                byte[] imageData = this.GetManager<IFotoOfertaManager>().GetImageFromOferta(id);
                resultat = File(imageData, "image/jpg");
            }
            catch (Exception ex)
            {
                Logger.ErrorFormat(ex, "AjaxController.GetImage({0})", id);
                resultat = null;
            }
            Logger.Info("FI - GET: /Ajax/GetImage/" + id.ToString());
            return resultat;
        }

    }
}
