﻿using System.Web.Mvc;
using Gaudeix.Common.Interfaces.Manager;
using Gaudeix.Manager.Infrastructure.Factory;
using Gaudeix.Web.Infrastructure.Controllers;
using Gaudeix.Common.Exceptions;

namespace Gaudeix.Web.Controllers
{
    /// <summary>
    /// Controlador d'operacions sobre l'enviament de correus
    /// </summary>
    public class MailController : BaseController
    {
        #region Actions del controller
        // GET: /Mail/ProcessMail
        public ActionResult ProcessMail()
        {
            Logger.Info("INICI - GET: /Mail/ProcessMail");
            bool procesOk = false;
            try
            {
                // Buidem la cua de correus pendents
                ICuaCorreuManager manager = this.GetManager<ICuaCorreuManager>();
                manager.ProcessMailQueue();
                procesOk = true;
            }
            catch (GaudeixBusinessException ex)
            {
                this.Logger.Error("Error al processar la cua de correus pendents", ex);
                procesOk = false;
            }

            JsonResult result = new JsonResult();
            result.JsonRequestBehavior = JsonRequestBehavior.AllowGet;
            result.Data = new { success = procesOk };
            Logger.Info("FI - GET: /Mail/ProcessMail");
            return result;
        }

        //GET: /Mail/ProcessOfertes
        public ActionResult ProcessOfertes()
        {
            Logger.Info("INICI - GET: /Mail/ProcessOfertes");
            bool procesOk = false;
            try
            {
                // Buidem la cua de correus pendents
                ICuaCorreuManager manager = this.GetManager<ICuaCorreuManager>();
                manager.ProcessMailOfertes();
                procesOk = true;
            }
            catch (GaudeixBusinessException ex)
            {
                this.Logger.Error("Error al processar l'enviament de correus d'ofertes", ex);
                procesOk = false;
            }

            JsonResult result = new JsonResult();
            result.JsonRequestBehavior = JsonRequestBehavior.AllowGet;
            result.Data = new { success = procesOk };
            Logger.Info("FI - GET: /Mail/ProcessOfertes");
            return result;
        }
        #endregion
    }
}
